***THIS PROGRAM PRODUCES ALL OF THE TABLES AND FIGURES for Chetty, Hendren, and Katz (AER 2015)
***THIS PROGRAM STARTS FROM HUD MTO data and a dataset constructed from tax records containing earnings and other information for these individuals by upstream SAS code (not included here)
***The data themselves are confidential, so the results can only be reproduced by obtaining access to the MTO data from HUD and obtaining permission to analyze these data at the IRS

local filename "mto_tables_final"
capture log close `filename'
local d = td(`c(current_date)')
local t = tc(`c(current_time)')
local tstamp = string(year(`d'))+string(month(`d'),"%02.0f")+string(day(`d'),"%02.0f")+"_"+string(hh(`t'),"%02.0f")+string(mm(`t'),"%02.0f")+string(ss(`t'),"%02.0f")
log using C:/Users/m2fqb/Documents/mto/logs/`filename'_`tstamp'.log, replace name(`filename')

/* This version current as of 09/14/2015

Written by Jamie Fogel, revised by Ben Scuderi, and based on original code written by Raj Chetty and Nathan Hendren.

The program is organized into the following sections:
	
	0. Setup Code Block - define relevant macros and programs
	1. Data Preparation 
		a. Clean MTO data to get rid of duplicates and invalid SSN's
		b. Merge MTO data with other data sets
			- mto_merge_v5.dta - IRS data
			- zip5_characteristics.dta - Zip code characteristics
			- mto_merge_v1_irsyob.dta - Year of birth from SSA records (taken from IRS)
			- mto_dadinfo.dta - Fertility and father information from IRS records
		c. Recode and generate new variables for use in regressions
	2. Main Tables 
		Table 1 - Comparison of control, experimental, and section 8 group means for pre-randomization control variables. 
			Full set of controls used in Appendix Table 1A; subset used in table 1 
		(Note: Table 2 is produced by Larry Katz's RAs and is not in this code)
		Table 3 - Impact on Income
		Table 4 - Impact on College Attendance and College Quality
		Table 5 - Impacts on Fertility
		Table 6 - Neighborhood characteristics
		Table 7 - Heterogeneity by gender
		Table 8 - Exposure Time Linear Models for Kids
		Table 9 - Income Outcomes for Adults
		Table 10 - Comparison to MTO Final Impacts Evaluation
		Table 11 - Multiple comparisons F-tests
		Table 12 - Impact on Tax Revenue
	3. Appendix Tables - Appendix tables 3-6, 8, 9, and 10 replicate main tables 3-6, 8, 9 and 12 respectively under two alternative specifications:	
			1) Include the full set of baseline covariates listed in appendix table 1a
			2) Report treatment-on-treated (TOT) IV results
		Appendix Table 1A - Summary stats for full set of pre-randomaization controls (see table 1)
		Appendix Table 1B - Summary stats for all variables used as dependent variables
		Appendix Table 3A - Impact on Income (Full set of covariates)
		Appendix Table 3B - Impact on Income (TOT)
		Appendix Table 3C - Income Decomposition 
		Appendix Table 4A - Impact on College Attendance and College Quality (Full set of covariates)
		Appendix Table 4B - Impact on College Attendance and College Quality (TOT)
		Appendix Table 5A - Impact on Fertility (Full set of covariates)
		Appendix Table 5B - Impact on Fertility (TOT)
		Appendix Table 6A - Impact on Neighborhood characteristics (Full set of covariates)
		Appendix Table 6B - Impact on Neighborhood characteristics (TOT)
		Appendix Table 7A - Heterogeneity by Race
		Appendix Table 7B - Heterogeneity by Site
		Appendix Table 8A - Exposure Time Linear Models for Kids (Full set of covariates)
		Appendix Table 8B - Exposure Time Linear Models for Kids (TOT)
		Appendix Table 9A - Income Outcomes for Adults (Full set of covariates)
		Appendix Table 9B - Income Outcomes for Adults (TOT)
		Appendix Table 10A - Impact on Tax Revenue (Full set of covariates)
		Appendix Table 10B - Impact on Tax Revenue (TOT)
		Appendix Table 11 - Robustness to various age cutoffs
	4. Figures (Main and Appendix)
		Figure 1  - Impact on Income, estimated separately for income measured at ages 20-28
		Figure 2A - Impact on Income for different age bins (hockey stick)
		Figure 2B - Impact on College Quality for different age bins (hockey stick)
		Figure 3A - Impact on adult subjects' years of exposure to low-poverty neighborhoods by years since RA
		Figure 3B - Impact on adult subjects' individual earnings bys years since RA
	5. Robustness and Text Notes - Various one-off calculations that appear as notes in the main text, including:
		Balance tests for estimation sample in Table 3, Panel A, Column 3
		Impacts on college attendance and quality at older ages
		Hypothesis Test for Figure 1
*/

cd C:/Users/m2fqb/Documents/mto

* Define directory in which to output tables
global tabledir "C:/Users/m2fqb/Documents/mto/finaltables"

* Define cluster variable - family ID 
global cv famid_synthetic 

* Define sets of MTO covariates to be used in regressions
global x_vars "x_f_Ch_male	x_f_Ch_schplay	x_f_Ch_specmed	x_f_Ch_schplay_miss	age_at_ra	x_f_C1_expel	x_f_C1_behprb	x_f_C1_gifted	x_f_C1_lrnprb	x_f_C1_schcll	x_f_C2_hosp	x_f_C2_lowbw	x_f_C2_read	x_f_C1_behprb_miss	x_f_C1_expel_miss	x_f_C1_gifted_miss	x_f_C1_lrnprb_miss	x_f_C2_hosp_miss	x_f_C2_lowbw_miss	x_f_C2_read_miss	x_f_Hh_afdc	x_f_Hh_car	x_f_Hh_disabl	x_f_Hh_noteens	x_f_Hh_size2	x_f_Hh_size3	x_f_Hh_size4	x_f_Hh_victim	x_f_Hood_5y	x_f_Hood_chat	x_f_Hood_nbrkid	x_f_Hood_nofamily	x_f_Hood_nofriend	x_f_Hood_safenit	x_f_Hood_verydissat	x_f_Hous_fndapt	x_f_Hous_mov3tm	x_f_Hous_movdrgs	x_f_Hous_movschl	x_f_Hous_sec8bef	x_f_Ad_age2008	x_f_Ad_edged	x_f_Ad_edgradhs	x_f_Ad_edinsch	x_f_Ad_ethn_hisp	x_f_Ad_male	x_f_Ad_nevmarr	x_f_Ad_parentu18	x_f_Ad_race_black	x_f_Ad_race_other	x_f_Ad_working	x_f_Ad_edgradhs_miss		"

* Define significance stars
global stars "+ 0.10 * 0.05 ** 0.01"

* Define upper limit for trimming
global upper_trim = .

* Define program to add sample means, etc to regression tables
capture program drop addmeans
program define addmeans, rclass
	syntax [, addiv(name) cmeansby(varname)]
	tempvar e
	local depvar `e(depvar)'
	local cmdline `e(cmdline)'
	local cmd `e(cmd)'
	gen `e' = e(sample)
	su `depvar' if `e' [w=wt_totcore98]
	estadd scalar sample_mean = `r(mean)' 
	su `depvar' if `e' & ra_group==3 [w=wt_totcore98]
	estadd scalar sample_control_mean = `r(mean)' 
	
	if "`cmeansby'"!=""{
		levelsof `cmeansby', local(cmeansbylevels)
		foreach l of local cmeansbylevels {
			local t : type `cmeansby'
			if substr("`t'",1,3)=="str" su `depvar' if `e' & ra_group==3 & `cmeansby'=="`l'" [w=wt_totcore98]
			else 						su `depvar' if `e' & ra_group==3 & `cmeansby'==`l' [w=wt_totcore98]
			local `cmeansby'_`l' = `r(mean)'
			estadd local `cmeansby'_`l' ``cmeansby'_`l''
		}
	}
	
	foreach l in x_f_controls x_f_site c1 c2 c3 c4{
		local `l' = 0
	}
	
	
	local b : subinstr local cmdline "(tax_yr<=2012 & tax_yr>=2008)" "", count(local c1)
	local b : subinstr local cmdline "(tax_yr<=2012 & tax_yr>=2008)" "", count(local c2)
	
	local b : subinstr local cmdline "tax_yr==2012" "", count(local c3)
	local b : subinstr local cmdline "tax_yr==2009" "", count(local c4)
	
	if `c1' | `c2' 		local Sample "5 Inc Yrs"
	else if `c1' | `c4' local Sample "Tax Yr 2012"
	else local Sample ""
	estadd local Sample `Sample'
	
	tempvar tag num_indiv
	egen `tag' = tag(pid) if `e'
	egen `num_indiv' = total(`tag')
	su `num_indiv'
	local num_individuals = `r(max)'
	estadd local num_individuals `num_individuals'

	if "`cmd'"!="ivregress" & "`addiv'"!=""{
		noi di as err "Can only save IV first stage estimates if you are using ivregress2
	}
	if "`cmd'"=="ivregress" {
		if "`addiv'"=="" local addiv "`e(_estimates_name)'"
	
		local instrumented `e(instd)'
		local wc : word count `instrumented'

		local inst "`e(insts)'"
		local exog "`e(exogr)'"
		* Here I am only reporting the instruments that aren't included in the second stage
		local instruments_subset : list inst - exog

		* Control complier means
		su `depvar' if cmove_exp==1 & `e'==1
		local CCM_exp = `r(mean)' - _b[cmove_exp]
		estadd scalar CCM_exp = `CCM_exp' : `addiv' 
		
		su `depvar' if cmove_s8==1 & `e'==1
		local CCM_s8 = `r(mean)' - _b[cmove_s8]
		estadd scalar CCM_s8 = `CCM_s8 ' : `addiv' 
	}
	
end

* You must have the program ivregress2 installed. It can be downloaded from SSC.
* do C:/ado/personal/ivregress2.ado


****************************************************************************************************************************************************************
****************************************************************************************************************************************************************
*** Data preparation
****************************************************************************************************************************************************************
****************************************************************************************************************************************************************

****************************************************************************************************************************************************************
*Step 1.a: Clean MTO data to get rid of duplicates and invalid SSNs
****************************************************************************************************************************************************************

* Load in MTO data received from HUD
use C:\Users\m2fqb\Documents\mto\data\irs_out2_20140624.dta , clear

* Drop obs that receive no weight in the analysis and cohorts that are too young
drop if wt_Totcore98==0
drop if year(date(mtch_dob,"MDY"))>1991

* Generate a unique person identifier internally as we don't have an MTO id on the file
gen pid = _n

* Rename variable in lowercase to make them easier to use
rename ra_Grp_Exp ra_grp_exp
rename ra_Grp_S8 ra_grp_s8
rename wt_Totcore98 wt_totcore98
rename flag_SSNqual flag_ssn

* Observe that including those with flag_ssn>=3 leads to imbalance in the match, as it was obtained post-random assignment
gen flag_ssn_below3 = flag_ssn<=3
reg flag_ssn_below3 ra_grp_exp ra_grp_s8 [w=wt_totcore98]
drop flag_ssn_below3

* Therefore set SSN to missing if flag_ssn>=1 (virtually no one has flag_ssn==2)
* Note that we can get match rates closer to 90% if we use flag_ssn<=3, but this creates imbalance in match rates, so we would need to supplement by name-dob matches
replace mtch_ssn=. if flag_ssn>1

* Verify that we have no duplicate SSN's
duplicates report mtch_ssn if mtch_ssn~=.
assert r(unique_value)==r(N)


****************************************************************************************************************************************************************
*Step 1.b: Merge on external data 
****************************************************************************************************************************************************************

* Some minor cleaning of the tax data
preserve
* Created by /bod/soi2/econ/sma/s_matchkids/mto/mto_merge_v5.sas
use ./data/mto_merge_v5_output.dta, clear
rename *, lower
keep if ~missing(unmasked_tin) // keep only people who merged to databank
drop zip_* mtch_yob age_outcome mtch_dob par_zip4* // drop MTO variables
* Check that all income variables are missing before 1999
foreach v of varlist w2wages w2wages_spouse ssinc_ssa ssinc_rrb ssinc_ssa_spouse ssinc_rrb_spouse uiinc uiinc_spouse cpftloss wage_amt dpftloss hh_inc w2ssiui_inc w2ssiui_inc_spouse non_w2ssiui non_w2ssiui_spouse indv_inc indv_inc_spouse indv_earn indv_earn_spouse ssinc{
	qui count if !missing(`v') & tax_yr<1999
	assert r(N)==0
}
duplicates drop // create dataset unique on databank variables
isid mtch_ssn tax_yr // verify this fact
saveold ./data/mto_merge_v5_output_clean, replace
restore

* Merge MTO data with the tax data 
* mtch_ssn uniquely identifies the data when it is non-missing so this join works properly. Use joinby rather than merge because of missing mtch_ssn values
joinby mtch_ssn using ./data/mto_merge_v5_output_clean.dta, unmatched(master)
gen intaxdata = _merge == 3
drop _merge

* Merge on parent (claimer) zip code characteristics. Parent defined according to IRS dependent claiming
rename claimer_zipcode zip5
merge m:1 zip5 using zip5_characteristics, keep(1 3) nogen keepusing(poor_share_2000)
rename (zip5 poor_share_2000) (claimer_zipcode claimer_poverty)

* Merge on time-invariant characteristics of the MTO subjects' IRS zipcode
rename zipcode zip5
label variable zip5 "IRS zipcode"
merge m:1 zip5 using zip5_characteristics, keep(1 3)

* Rename birth year variable
rename ssa_yob cohort

* Generate mto cohort and replace IRS cohort with mto cohort if IRS cohort is missing
gen mto_cohort = year(date(mtch_dob,"MDY"))
replace cohort = mto_cohort if cohort==.

* Merge on data for all females on birth history, including info on dads
merge m:1 mtch_ssn using ./data/mto_merge_v5_dadinfo.dta , keep(match master) nogen


****************************************************************************************************************************************************************
*Step 1.c: Recode and generate new variables for use in regressions
****************************************************************************************************************************************************************

* College quality is in 2010 dollars while variables are in 2012 dollars. Inflate college quality to 2012 dollars
local cpi2010 = 0.9498
foreach v in  coll_qual_18 coll_qual_19 coll_qual_20 coll_qual_21 coll_qual_22 coll_qual_1821 {
	replace `v' = `v' / `cpi2010'
}

* Generate family ID variable
global fam_vars x_f_Ad* x_f_Hh_* x_f_Hood* x_f_Hous* x_f_site*
egen famid_synthetic = group($fam_vars) if wt_totcore98>0

* Set income to zero if negative in new variables with suffix "_trim"
foreach v in w2wages non_w2ssiui indv_earn ssinc uiinc indv_inc indv_inc_spouse hh_inc {
	gen `v'_trim = `v'
	replace `v'_trim=0 if `v'<0
}

* Winsorize hh_inc and indv_earn. These variables are only used in income decomposition (Appendix table 3)
gen hh_inc_trim100k = min(hh_inc_trim,100000)
gen indv_earn_trim100k = min(indv_earn_trim,100000)

* Generate age variables
gen age_outcome = tax_yr - cohort
gen age_at_ra = year(ra_date) - cohort

* Define MTO kid sample and adult sample to be used as sample restrictions in regressions
gen mto_kidsample = (f_svy_sample2007 == "YT" | f_svy_sample2007 ==  "EY" | f_svy_sample2007 ==  "YA") & cohort<=1991
gen mto_adultsample = (f_svy_sample2007 == "AD") | (f_svy_sample2007 == "ES")
drop if mto_kidsample==1 & age_at_ra==44 //This person is clearly miscoded as a kid

* Generate within-indivudal identifier. This can be used to restrict to 1 obs per person in regressions with time-invariant LHS vars
bys pid (tax_yr): gen pindex = _n

* Censor college variables by cohort - restrict to cohorts who are college-aged during years covered by our data
replace coll18   = . if cohort<1981|cohort>1994
replace coll19   = . if cohort<1980|cohort>1993
replace coll20   = . if cohort<1979|cohort>1992
replace coll21   = . if cohort<1978|cohort>1991
replace coll22   = . if cohort<1977|cohort>1990
replace coll1821 = . if cohort<1981|cohort>1991

forval a = 18/22 {
	replace coll_qual_`a' = . if coll`a'==.
}

* For interactions with ra_site in exposure time tables
gen age_at_ra_kids = age_at_ra if mto_kidsample==1

* Generate 5-yr earnings growth outcome variable 
tsset mtch_ssn tax_yr
gen indv_earn_growth_5yr = indv_earn_trim - l5.indv_earn_trim

* Takeup * randomization group interactions
gen cmove_exp = f_svy_cmove * ra_grp_exp 
gen cmove_s8 = f_svy_cmove * ra_grp_s8

* Pooled college vars - create a college attendance variable that is in long (one obs per person per year), rather than wide, form
gen coll_pool_1820 = .
gen coll_qual_pool_1820 = .
forval i=18/20{
	replace coll_pool_1820 = coll`i' if age_outcome==`i' 
	replace coll_qual_pool_1820 = coll_qual_`i' if age_outcome==`i' 
}

* Define fertility-related variables
gen dad_reported = dad_ssn != . if num_kids > 0 & num_kids < .
gen hasbirth = num_kids>0 & num_kids<. if gnd_ind=="F"
gen hasbirth_dad = dad_reported==1 & hasbirth==1 if gnd_ind=="F"
gen hasbirth_nodad = dad_reported==0 & hasbirth==1 if gnd_ind=="F"

* Recode missing taxes_paid to 0 and rename
replace totximf = 0 if missing(totximf)
gen net_income_taxes_paid = totximf - eic - addlchtx
replace net_income_taxes_paid = withhldg if filed1040==0
gen total_taxes_paid = totximf
replace total_taxes_paid = withhldg if filed1040==0
replace total_taxes_paid = 0 if missing(total_taxes_paid)

* Exposure time variables 
gen age_exp 		= age_at_ra*ra_grp_exp
gen age_s8 			= age_at_ra*ra_grp_s8
gen age_cmove_exp 	= age_at_ra*cmove_exp
gen age_cmove_s8 	= age_at_ra*cmove_s8

* Multiply fraction variables by 100 to express as percentages
foreach v in claimer_poverty coll_pool_1820 coll18 coll19 coll20 coll21 poor_share_2000 hhinc_2000 black_share singlemom_share hasbirth dad_reported hasbirth_dad hasbirth_nodad worked coll1821 f_svy_cmove teen_birth filed1040 married {
	gen `v'_x100 = `v' * 100
}

* SAVE ANALYSIS DATASET
save ./data/mto_work_v5.dta, replace


****************************************************************************************************************************************************************
****************************************************************************************************************************************************************
**** Main Tables 
****************************************************************************************************************************************************************
****************************************************************************************************************************************************************

****************************************************************************************************************************************************************
* Table 1 and Appendix Table 1a: Summary Statistics and Match Rates
****************************************************************************************************************************************************************

* Load MTO data
use ./data/mto_work_v5.dta, clear

* Define list of variable we want to include in Table 1 (exclude age dummies); Multiply [0,1] variables by 100 to express as percentages
local vars "intaxdata ${x_vars}"
foreach v of local vars{
	if !regexm("`v'", "[Aa]ge")	{
		gen `v'_x100 = `v' * 100
		local usevars "`usevars' `v'_x100"
	}
	else local usevars "`usevars' `v'"
}

* Below we calculate the mean of the LHS variable within the control group and then run a regression of the LHS var on experimental and section 8 dummies. 
* I write all of the output to a csv because it is difficult to get the formatting we want using Stata programs like esttab

* Open temp file to write table output to. This will be converted to the actual output, table1.csv, below
tempfile temp
capture file close outfile
file open outfile using `temp', write replace
file write outfile ",ControlMean_b13,ExpCoef_b13,S8Coef_b13,ControlMean_13a,ExpCoef_13a,S8Coef_13a" _n

* Define an output format for estimates
global fmt "%9.1f"

* Keep track of total number of coefficients estimated and number of significant coefficients for text notes
local coef_count = 0
local p10_count = 0
local p05_count = 0
local p01_count = 0

local i=1
foreach v of local usevars {

	********************
	* Below 13 	
	********************
	
	* Calculate mean of each variable within control group
	su `v' if `intaxdata_cond' ra_group==3 & mto_kidsample==1 & pindex==1 & age_at_ra<13 [w=wt_totcore98]
	local cont_b13 = `r(mean)'	
	
	* Test for statistically significant deviations from control mean in experimental and section 8 groups
	reg `v' ra_grp_exp ra_grp_s8 x_f_site* if `intaxdata_cond' mto_kidsample==1 & pindex==1 & age_at_ra<13 [w=wt_totcore98], cluster(${cv})
	local coef_count = `coef_count'+2
	
	* Store coefficients and significance stars to be printed below
	local b_exp_b13  = _b[ra_grp_exp]
	local se_exp_b13 = _se[ra_grp_exp]
	local star_exp_b13 = ""
	if abs(`b_exp_b13'/`se_exp_b13')>invnormal(.95) & abs(`b_exp_b13'/`se_exp_b13')<=invnormal(.975) { 
		local star_exp_b13 = "+"
		local p10_count = `p10_count'+1
	}
	if abs(`b_exp_b13'/`se_exp_b13')>invnormal(.975) & abs(`b_exp_b13'/`se_exp_b13')<=invnormal(.995) { 
		local star_exp_b13 = "*"
		local p05_count = `p05_count'+1
	}
	if abs(`b_exp_b13'/`se_exp_b13')>invnormal(.995) & abs(`b_exp_b13'/`se_exp_b13')<. {
		local star_exp_b13 = "**"
		local p01_count = `p01_count'+1
	}
	local b_s8_b13  = _b[ra_grp_s8]
	local se_s8_b13 = _se[ra_grp_s8]
	local star_s8_b13 = ""
	if abs(`b_s8_b13'/`se_s8_b13')>invnormal(.95) & abs(`b_s8_b13'/`se_s8_b13')<=invnormal(.975) {
		local star_s8_b13 = "+"
		local p10_count = `p10_count'+1
	}
	if abs(`b_s8_b13'/`se_s8_b13')>invnormal(.975) & abs(`b_s8_b13'/`se_s8_b13')<=invnormal(.995) {
		local star_s8_b13 = "*"
		local p05_count = `p05_count'+1
	}
	if abs(`b_s8_b13'/`se_s8_b13')>invnormal(.995) & abs(`b_s8_b13'/`se_s8_b13')<. {
		local star_s8_b13 = "**"
		local p01_count = `p01_count'+1
	}
	* Use value of 99999 as flag for missing coefficient to be parsed and dropped below
	if _b[ra_grp_exp]==0 & _se[ra_grp_exp]==0{
		local b_exp_b13 = 99999
		local se_exp_b13 = 99999
		local star_exp_b13 = ""
	}
	if _b[ra_grp_s8]==0 & _se[ra_grp_s8]==0{
		local b_s8_b13 = 99999
		local se_s8_b13 = 99999
		local star_s8_b13 = ""
	}
	
	********************
	* 13 Above
	********************
	
	* x_f_C2 vars not defined for age_at_ra>=13
	if !regexm("`v'", "x_f_C2"){
	
	* Calculate mean of each variable within control group
	su `v' if `intaxdata_cond' ra_group==3 & mto_kidsample==1 & pindex==1 & age_at_ra>=13 [w=wt_totcore98]
	local cont_13a = `r(mean)'
	
	* Test for statistically significant deviations from control mean in experimental and section 8 groups
	reg `v' ra_grp_exp ra_grp_s8 x_f_site* if `intaxdata_cond' mto_kidsample==1 & pindex==1 & age_at_ra>=13 [w=wt_totcore98], cluster(${cv})
	local coef_count = `coef_count'+2
	
	* Store coefficients and significance stars to be printed below
	local b_exp_13a  = _b[ra_grp_exp]
	local se_exp_13a = _se[ra_grp_exp]
	local star_exp_13a = ""
	if abs(`b_exp_13a'/`se_exp_13a')>invnormal(.95) & abs(`b_exp_13a'/`se_exp_13a')<=invnormal(.975) {
		local star_exp_13a = "+"
		local p10_count = `p10_count'+1
	}
	if abs(`b_exp_13a'/`se_exp_13a')>invnormal(.975) & abs(`b_exp_13a'/`se_exp_13a')<=invnormal(.995) {
		local star_exp_13a = "*"
		local p05_count = `p05_count'+1
	}
	if abs(`b_exp_13a'/`se_exp_13a')>invnormal(.995) & abs(`b_exp_13a'/`se_exp_13a')<. {
		local star_exp_13a = "**"
		local p01_count = `p01_count'+1
	}
	local b_s8_13a  = _b[ra_grp_s8]
	local se_s8_13a = _se[ra_grp_s8]
	local star_s8_13a = ""
	if abs(`b_s8_13a'/`se_s8_13a')>invnormal(.95) & abs(`b_s8_13a'/`se_s8_13a')<=invnormal(.975) {
		local star_s8_13a = "+"
		local p10_count = `p10_count'+1
	}
	if abs(`b_s8_13a'/`se_s8_13a')>invnormal(.975) & abs(`b_s8_13a'/`se_s8_13a')<=invnormal(.995) {
		local star_s8_13a = "*"
		local p05_count = `p05_count'+1
	}
	if abs(`b_s8_13a'/`se_s8_13a')>invnormal(.995) & abs(`b_s8_13a'/`se_s8_13a')<. {
		local star_s8_13a = "**"
		local p01_count = `p01_count'+1
	}
	if _b[ra_grp_exp]==0 & _se[ra_grp_exp]==0{
		local b_exp_13a = 99999
		local se_exp_13a = 99999
		local star_exp_13a = ""
	}	
	if _b[ra_grp_s8]==0 & _se[ra_grp_s8]==0{
		local b_s8_13a = 99999
		local se_s8_13a = 99999
		local star_s8_13a = ""
	}
	}
	else{
	local cont_13a = 99999
	foreach g in exp s8{
		local b_`g'_13a = 99999
		local se_`g'_13a = 99999
		local star_`g'_13a = ""
	}
	}
	
	* Print means, coefficients, standard errors, and significance stars to output csv file
	local rowname : word `i' of `vars'
	file write outfile `"`rowname',=""' ${fmt} (`cont_b13') `"", =""' ${fmt} (`b_exp_b13') `"`star_exp_b13'", =""' ${fmt} (`b_s8_b13') `"`star_s8_b13'", =""' ${fmt} (`cont_13a') `"", =""' ${fmt} (`b_exp_13a') `"`star_exp_13a'", =""' ${fmt} (`b_s8_13a') `"`star_s8_13a'""' _n
	file write outfile `" , ,="("' ${fmt} (`se_exp_b13') `")",="("'${fmt} (`se_s8_b13') `")", ,="("' ${fmt} (`se_exp_13a') `")",="("' ${fmt} (`se_s8_13a') `")""' _n

	local i=`i'+1
	
	* Want to impose below restriction for all regressions except the first, which has intaxdata on the LHS
	local intaxdata_cond "intaxdata==1 & "
}

local ++i
* Count number of observation within each sample subgroup 
count if ra_group==3 & mto_kidsample==1 & age_at_ra<13 & intaxdata==1 & pindex==1 
local count_cont_b13 = r(N)
count if ra_group==1 & mto_kidsample==1 & age_at_ra<13 & intaxdata==1 & pindex==1 
local count_exp_b13 = r(N)
count if ra_group==2 & mto_kidsample==1 & age_at_ra<13 & intaxdata==1 & pindex==1 
local count_s8_b13 = r(N)
count if ra_group==3 & mto_kidsample==1 & age_at_ra>=13 & intaxdata==1 & pindex==1 
local count_cont_13a = r(N)
count if ra_group==1 & mto_kidsample==1 & age_at_ra>=13 & intaxdata==1 & pindex==1 
local count_exp_13a = r(N)
count if ra_group==2 & mto_kidsample==1 & age_at_ra>=13 & intaxdata==1 & pindex==1 
local count_s8_13a = r(N)

* Print number of observations in subgroup at bottom of table
file write outfile "Count, `count_cont_b13',`count_exp_b13',`count_s8_b13',`count_cont_13a',`count_exp_13a',`count_s8_13a'" _n
file close outfile

capture file close infile
file open infile using `temp', read

* Open csv file to write table 1 to
file open outfile using ${tabledir}/table1.csv, write replace

* Write each line from the temporary table1 file to the final output table. Replace 99999 placeholders for missing coefficients with blanks
file read infile line
while r(eof)==0{
	local out = subinstr(trim(itrim(`"`line'"'))," ","",.)
	local out = subinstr(`"`out'"', "(99999.0)", "", .)
	local out = subinstr(`"`out'"', "99999.0", "", .)
	file write outfile `"`out'"' _n
	file read infile line
}
file close infile 
file close outfile

* Write a set of notes for use in the text
capture file close textnotes
file open textnotes using ${tabledir}/text_notes.txt, write replace
file write textnotes "`coef_count' total coefficients" _n
file write textnotes "`p10_count' coefficients significant with .05<p<.1" _n
file write textnotes "`p05_count' coefficients significant with .01<p<.05" _n
file write textnotes "`p01_count' coefficients significant with p<.01" _n
file close textnotes


****************************************************************************************************************************************************************
**** Table 3: Impact on Income  ****
****************************************************************************************************************************************************************

*Load analysis sample, restricting to matched obs
use ./data/mto_work_v5 if intaxdata==1, clear

* Age < 13
global agecond "age_at_ra < 13"
eststo clear
_eststo w2wages_base: 	reg w2wages_trim ra_grp_exp ra_grp_s8 x_f_site* 									if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_base: 		reg indv_earn_trim ra_grp_exp ra_grp_s8 x_f_site* 									if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_basecon: 	reg indv_earn_trim ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 						if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_base_TOT: ivregress2 2sls indv_earn_trim (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site*	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv}) first
	addmeans
	local first_stages "`r(first_stages)'"
_eststo indv_base26: 	reg indv_earn_trim ra_grp_exp ra_grp_s8 x_f_site* 									if mto_kidsample == 1  									& age_outcome==26 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_base_2012: reg indv_earn_trim ra_grp_exp ra_grp_s8 x_f_site* 									if mto_kidsample == 1 & tax_yr==2012 					& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo work_base: 		reg worked_x100 ra_grp_exp ra_grp_s8 x_f_site* 										if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hh_base: 		reg hh_inc_trim ra_grp_exp ra_grp_s8 x_f_site* 										if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_grth5: 	reg indv_earn_growth_5yr ra_grp_exp ra_grp_s8 x_f_site* 							if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
	
esttab, nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages'  CCM_exp CCM_s8 x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*x_f* ) starlevels( ${stars})
esttab using ${tabledir}/table3a_base_below13.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages'  CCM_exp CCM_s8 x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*x_f* ) starlevels( ${stars})

* Age >= 13
global agecond "age_at_ra >= 13"
eststo clear
_eststo w2wages_base: 	reg w2wages_trim ra_grp_exp ra_grp_s8 x_f_site* 									if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_base: 		reg indv_earn_trim ra_grp_exp ra_grp_s8 x_f_site* 									if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_basecon: 	reg indv_earn_trim ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 						if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_base_TOT: ivregress2 2sls indv_earn_trim (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site*	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv}) first
	addmeans
	local first_stages "`r(first_stages)'"
_eststo indv_base26: 	reg indv_earn_trim ra_grp_exp ra_grp_s8 x_f_site* 									if mto_kidsample == 1  									& age_outcome==26 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_base_2012: reg indv_earn_trim ra_grp_exp ra_grp_s8 x_f_site* 									if mto_kidsample == 1 & tax_yr==2012 					& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo work_base: 		reg worked_x100 ra_grp_exp ra_grp_s8 x_f_site* 										if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hh_base: 		reg hh_inc_trim ra_grp_exp ra_grp_s8 x_f_site* 										if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_grth5: 	reg indv_earn_growth_5yr ra_grp_exp ra_grp_s8 x_f_site* 							if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans

esttab using ${tabledir}/table3b_base_13above.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages'  CCM_exp CCM_s8 x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*x_f* ) starlevels( ${stars})


****************************************************************************************************************************************************************
**** Table 4: Impact on College Attendance and College Quality ****
****************************************************************************************************************************************************************

* Age < 13
global agecond "age_at_ra<13"
eststo clear
_eststo coll_pool_1820:	reg coll_pool_1820_x100   	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond}  				 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll18: 		reg coll18_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll19: 		reg coll19_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll20: 		reg coll20_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll21: 		reg coll21_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820: 		reg coll_qual_pool_1820 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} 				 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq18: 			reg coll_qual_18 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq19: 			reg coll_qual_19 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq20: 			reg coll_qual_20 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq21: 			reg coll_qual_21 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
	
esttab using ${tabledir}/table4a_coll_below13.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(x_f*) starlevels( ${stars})

* Age >= 13
global agecond "age_at_ra>=13"
eststo clear
_eststo coll_pool_1820:	reg coll_pool_1820_x100   	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond}  				 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll18: 		reg coll18_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll19: 		reg coll19_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll20: 		reg coll20_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll21: 		reg coll21_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820: 		reg coll_qual_pool_1820 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} 				 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq18: 			reg coll_qual_18 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq19: 			reg coll_qual_19 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq20: 			reg coll_qual_20 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq21: 			reg coll_qual_21 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
	
esttab using ${tabledir}/table4b_coll_13above.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(x_f*) starlevels( ${stars})


****************************************************************************************************************************************************************
**** Table 5: Impacts on Fertility ****
****************************************************************************************************************************************************************

* Age < 13
global agecond "age_at_ra<13"
eststo clear
_eststo married: 		reg married_x100		ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 				& ${agecond} 				[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_m: 		reg married_x100		ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 				& ${agecond} & gnd_ind=="M" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_f: 		reg married_x100		ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 				& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo anybirth: 		reg hasbirth_x100 		ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012 				& age_outcome>=21  				& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo teenbirth: 		reg teen_birth_x100 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012 				& age_outcome>=21  				& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hasbirth_dad: 	reg hasbirth_dad_x100 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012 				& age_outcome>=21 & hasbirth==1 & ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hasbirth_nodad: reg hasbirth_nodad_x100	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012 				& age_outcome>=21   			& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans

esttab , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals exp_exp_same_p x_f_controls Sample sample_control_mean, fmt(0 4 1)) unstack drop(x_f_site* ) starlevels( ${stars})
esttab using ${tabledir}/table5a_teenbirth_below13.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals exp_exp_same_p x_f_controls Sample sample_control_mean, fmt(0 4 1)) unstack drop(x_f_site* ) starlevels( ${stars})

* Age >= 13
global agecond "age_at_ra>=13"
eststo clear
_eststo married: 		reg married_x100		ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 				& ${agecond} 				[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_m: 		reg married_x100		ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 				& ${agecond} & gnd_ind=="M" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_f: 		reg married_x100		ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008)	& age_outcome>=24	 			& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo anybirth: 		reg hasbirth_x100 		ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012 				& age_outcome>=21  				& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo teenbirth: 		reg teen_birth_x100 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012 				& age_outcome>=21  				& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hasbirth_dad: 	reg hasbirth_dad_x100 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012 				& age_outcome>=21 & hasbirth==1 & ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hasbirth_nodad: reg hasbirth_nodad_x100	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012 				& age_outcome>=21   			& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans

esttab  , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals exp_exp_same_p x_f_controls Sample sample_control_mean, fmt(0 4 1)) unstack drop(x_f_site* ) starlevels( ${stars})
esttab using ${tabledir}/table5b_teenbirth_13above.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals exp_exp_same_p x_f_controls Sample sample_control_mean, fmt(0 4 1)) unstack drop(x_f_site* ) starlevels( ${stars})


****************************************************************************************************************************************************************
**** Table 6 - Neighborhood characteristics ****
****************************************************************************************************************************************************************

* Age < 13	
global agecond "age_at_ra < 13"						
eststo clear

_eststo poor_share_5: 		reg poor_share_2000_x100 	ra_grp_exp ra_grp_s8 x_f_site* 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hhinc_5: 			reg hhinc_2000 				ra_grp_exp ra_grp_s8 x_f_site* 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo black_share_5: 		reg black_share_x100 		ra_grp_exp ra_grp_s8 x_f_site* 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo singlemom_share: 	reg singlemom_share_x100  	ra_grp_exp ra_grp_s8 x_f_site* 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans

esttab using ${tabledir}/table6a_nbhd_firm_below13.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3)))  stats(N num_individuals x_f_controls Sample sample_control_mean, fmt(0 0 1)) drop(x_f_site*) starlevels( ${stars}) addnotes("We are missing some zip5 characteristics for a few zip5s, which is why cols 1, 4-6 don't have same # obs")

* Age >= 13
global agecond "age_at_ra>=13"						
eststo clear

_eststo poor_share_5: 		reg poor_share_2000_x100 	ra_grp_exp ra_grp_s8 x_f_site* 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo poor_share_2012: 	reg poor_share_2000_x100 	ra_grp_exp ra_grp_s8 x_f_site* 	if mto_kidsample == 1 & tax_yr==2012 		 			& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hhinc_5: 			reg hhinc_2000 				ra_grp_exp ra_grp_s8 x_f_site* 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo black_share_5: 		reg black_share_x100 		ra_grp_exp ra_grp_s8 x_f_site* 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo singlemom_share: 	reg singlemom_share_x100  	ra_grp_exp ra_grp_s8 x_f_site* 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans

esttab using ${tabledir}/table6b_nbhd_firm_13above.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3)))  stats(N num_individuals x_f_controls Sample sample_control_mean, fmt(0 0 1)) drop(x_f_site*) starlevels( ${stars}) addnotes("We are missing some zip5 characteristics for a few zip5s, which is why cols 1, 4-6 don't have same # obs")


****************************************************************************************************************************************************************
**** Table 7 - Heterogeneity by Gender ****
****************************************************************************************************************************************************************

* Age < 13, Male
global agecond "age_at_ra < 13"
eststo clear
_eststo indv_base_m: 		reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& ${agecond} & x_f_Ch_male == 1 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820_m: 			reg coll_qual_pool_1820 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1				 									& ${agecond} & x_f_Ch_male == 1 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo poor_share_2000_m: 	reg poor_share_2000_x100 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012 									& ${agecond} & x_f_Ch_male == 1 [w=wt_totcore98], cluster(${cv})
	addmeans

* Age < 13, Female
_eststo indv_base_f: 		reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& ${agecond} & x_f_Ch_male == 0 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820_f: 			reg coll_qual_pool_1820 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 													& ${agecond} & x_f_Ch_male == 0 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo poor_share_2000_f: 	reg poor_share_2000_x100 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012 									& ${agecond} & x_f_Ch_male == 0 [w=wt_totcore98], cluster(${cv})
	addmeans

esttab using ${tabledir}/table7a_below13_gender.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals x_f_controls Sample sample_control_mean, fmt(0 0 1)) unstack drop(x_f_site*) starlevels( ${stars})

* Age >= 13, Male
global agecond "age_at_ra >= 13"
eststo clear
_eststo indv_base_m: 		reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& ${agecond} & x_f_Ch_male == 1 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820_m: 			reg coll_qual_pool_1820 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 													& ${agecond} & x_f_Ch_male == 1 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo poor_share_2000_m: 	reg poor_share_2000_x100 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012 									& ${agecond} & x_f_Ch_male == 1 [w=wt_totcore98], cluster(${cv})
	addmeans

* Age >= 13, Female
_eststo indv_base_f: 		reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& ${agecond} & x_f_Ch_male == 0 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820_f: 			reg coll_qual_pool_1820 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 													& ${agecond} & x_f_Ch_male == 0 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo poor_share_2000_f: 	reg poor_share_2000_x100 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012 									& ${agecond} & x_f_Ch_male == 0 [w=wt_totcore98], cluster(${cv})
	addmeans

esttab using ${tabledir}/table7b_13above_gender.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals x_f_controls Sample sample_control_mean, fmt(0 0 1)) unstack drop(x_f_site*) starlevels( ${stars})


****************************************************************************************************************************************************************
**** Table 8: Exposure Time Linear Models for Kids ****
****************************************************************************************************************************************************************

global age_controls "i.age_at_ra_kids#i.ra_site"

eststo clear
_eststo exp_indv_earn: 			reg indv_earn_trim 				ra_grp_exp ra_grp_s8 age_exp age_s8 ${age_controls} if mto_kidsample==1 &(tax_yr<=2012 & tax_yr>=2008)	& age_outcome>=24 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo exp_hh_inc: 			reg hh_inc_trim 				ra_grp_exp ra_grp_s8 age_exp age_s8 ${age_controls} if mto_kidsample==1 &(tax_yr<=2012 & tax_yr>=2008)	& age_outcome>=24 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo exp_hh_inc26: 			reg hh_inc_trim 				ra_grp_exp ra_grp_s8 age_exp age_s8 ${age_controls} if mto_kidsample==1 								& age_outcome==26 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo exp_collqual1820: 		reg coll_qual_pool_1820 		ra_grp_exp age_exp ra_grp_s8 age_s8 ${age_controls} if mto_kidsample==1 													[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo exp_married: 			reg married_x100 				ra_grp_exp age_exp ra_grp_s8 age_s8 ${age_controls} if mto_kidsample==1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo exp_poor_share_2000: 	reg poor_share_2000_x100 		ra_grp_exp age_exp ra_grp_s8 age_s8 ${age_controls} if mto_kidsample==1 &(tax_yr<=2012 & tax_yr>=2008)	& age_outcome>=24 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo exp_tot_taxes: 			reg total_taxes_paid 			ra_grp_exp ra_grp_s8 age_exp age_s8 ${age_controls} if mto_kidsample==1 &(tax_yr<=2012 & tax_yr>=2008)	& age_outcome>=24 	[w=wt_totcore98], cluster(${cv})
	addmeans
	
esttab using ${tabledir}/table8_exposure.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages' x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*age_at_ra_kids*) starlevels( ${stars})
esttab  , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals  `first_stages'  x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*age_at_ra_kids*) starlevels( ${stars})


****************************************************************************************************************************************************************
**** Table 9: Income Outcomes for Adults ****
****************************************************************************************************************************************************************

eststo clear
_eststo indv_earn5: 	reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* 				if mto_adultsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_earn5con: 	reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 	if mto_adultsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_earn2012: 	reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* 				if mto_adultsample == 1 & tax_yr==2012 					& age_outcome>=24 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo worked5: 		reg worked_x100 			ra_grp_exp ra_grp_s8 x_f_site* 				if mto_adultsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hh_inc5: 		reg hh_inc_trim 			ra_grp_exp ra_grp_s8 x_f_site* 				if mto_adultsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 [w=wt_totcore98], cluster(${cv})
	addmeans	
	
esttab using ${tabledir}/table9_adult.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(x_f*) starlevels( ${stars})


****************************************************************************************************************************************************************
**** Table 10: Comparison to MTO Final Impacts Evaluation ****
****************************************************************************************************************************************************************

eststo clear
_eststo indv_2012_l13: 				reg indv_earn_trim 		ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &	(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& age_at_ra<13 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_2012_full: 			reg indv_earn_trim 		ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &	(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 					[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_2008_l13: 				reg indv_earn_trim 		ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &	tax_yr==2008				 	& age_outcome>=24 	& age_at_ra<13 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_2008_full: 			reg indv_earn_trim 		ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &	tax_yr==2008				 	& age_outcome>=24				 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_2012_l13_1621: 		reg indv_earn_trim 		ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &	age_outcome>=16 & age_outcome<=21 					& age_at_ra<13 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_only2008_full_1621: 	reg indv_earn_trim 		ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &	tax_yr==2008					& age_outcome>=16 & age_outcome<=21 [w=wt_totcore98], cluster(${cv})
	addmeans

esttab using ${tabledir}/table10.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals sample_control_mean , fmt(0 0 1)) drop(x_f*) starlevels( ${stars})


****************************************************************************************************************************************************************
**** Table 11: Multiple Comparison Tests ****
****************************************************************************************************************************************************************

use ./data/mto_work_v5 if intaxdata==1, clear        

global cv famid_synthetic 
cap g below13 = age_at_ra<13 if mto_kidsample==1

* Panel A

mat m = J(6,6,.)

local indv_earn_trim 		"mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24"
local hh_inc_trim			"mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24"
local coll_pool_1820_x100 	"mto_kidsample == 1"
local coll_qual_pool_1820 	"mto_kidsample == 1"
local married 				"mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24"
local poor_share_2000_x100 	"mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24"

local i = 1
foreach v in indv_earn_trim hh_inc_trim coll_pool_1820_x100 coll_qual_pool_1820 married poor_share_2000_x100 {
	
	xi: reg `v' i.below13*ra_grp_exp i.below13*ra_grp_s8 x_f_site* if ``v'' [w=wt_totcore98], cluster(${cv})
	
	test ra_grp_exp _IbelXra_gr_1
	mat m[1,`i'] = r(F)
	mat m[2,`i'] = r(p)
	test ra_grp_s8 _IbelXra_gra1 
	mat m[3,`i'] = r(F)
	mat m[4,`i'] = r(p)
	test ra_grp_exp _IbelXra_gr_1 ra_grp_s8 _IbelXra_gra1 
	mat m[5,`i'] = r(F)
	mat m[6,`i'] = r(p)

	local ++i
}

mat rownames m = exp_v_control_F exp_v_control_p sec8_v_control_F sec8_v_control_p exp_sec8_v_control_F exp_sec8_v_control_p
mat colnames m = indv_earn hh_inc coll_attd coll_qual poor_share married
estout matrix(m , fmt(4)) 

esttab matrix(m, fmt(4)) using ${tabledir}/table11_mult_comparison_tests_a.csv, replace

* Panel B

cap mat drop m

replace  x_f_Ad_race_black = round(x_f_Ad_race_black)
replace  x_f_Ad_race_other = round(x_f_Ad_race_other)

foreach var of varlist x_f_*{
	local a = ""
	if regexm("`var'", "(x_f_site_)(.+)")		local a = regexs(2) 
	if regexm("`var'", "(x_f_Ch_)(.+)")			local a = regexs(2)
	if regexm("`var'", "(x_f_Ad_race_)(.+)")	local a = regexs(2) 
	if "`a'"!=""    rename `var' `a'       
}

rename ra_grp_exp exp
rename ra_grp_s8  s8

local exp "i.exp*i.below13 i.exp*balt i.exp*bos i.exp*chi i.exp*la i.exp*male i.exp*black i.exp*other"
local s8  "i.s8*i.below13  i.s8*balt  i.s8*bos  i.s8*chi  i.s8*la  i.s8*male  i.s8*black  i.s8*other "

* Everything needs to be interacted with ra_grp_exp and s8
* Are there heterogeneous treatment effects in any subgroup?
* test ra_grp_exp ra_grp_s8 ra_grp_exp*(site, gender, race, below 13) ra_grp_s8*(site, gender, race, below 13)
* test once with all exp and s8, once separately for exp and s8

mat m = J(6,6,.)

local indv_earn_trim 		"mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24"
local coll_pool_1820_x100 	"mto_kidsample == 1"
local coll_qual_pool_1820 	"mto_kidsample == 1 & age_at_ra<23"
local married 				"mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24"
local poor_share_2000_x100 	"mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24"

local i = 1
foreach v in indv_earn_trim hh_inc_trim coll_pool_1820_x100 coll_qual_pool_1820 married poor_share_2000_x100 {
	xi: reg `v'	`exp' `s8' if ``v''	[w=wt_totcore98], cluster(${cv})
	
	testparm _Iexp*
	mat m[1,`i'] = r(F)
	mat m[2,`i'] = r(p)
	testparm _Is8*
	mat m[3,`i'] = r(F)
	mat m[4,`i'] = r(p)
	testparm _Iexp* _Is8*
	mat m[5,`i'] = r(F)
	mat m[6,`i'] = r(p)

	local ++i
}

mat rownames m = exp_v_control_F exp_v_control_p sec8_v_control_F sec8_v_control_p exp_sec8_v_control_F exp_sec8_v_control_p
mat colnames m = indv_earn hh_inc coll_attd coll_qual poor_share married
estout matrix(m , fmt(4)) 

esttab matrix(m, fmt(4)) using ${tabledir}/table11_mult_comparison_tests_b.csv , replace

****************************************************************************************************************************************************************
**** Table 12: Tax Revenue ****
****************************************************************************************************************************************************************

* Age < 13
eststo clear
global agecond "age_at_ra<13"
eststo filed1040_5: 			reg filed1040_x100 ra_grp_exp ra_grp_s8 									x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008)	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
eststo total_taxes_paid_5: 		reg total_taxes_paid ra_grp_exp ra_grp_s8 									x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
eststo total_taxes_paid_TOT_5: ivregress2 2sls total_taxes_paid (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv}) first
	addmeans
	local first_stages "`r(first_stages)'"

esttab using ${tabledir}/table12a_tax_below13.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages' CCM_exp CCM_s8 x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*x_f* ) starlevels( ${stars})

* Age >= 13
eststo clear
global agecond "age_at_ra>=13"
eststo filed1040_5: 			reg filed1040_x100 ra_grp_exp ra_grp_s8 									x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008)	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
eststo total_taxes_paid_5: 	reg total_taxes_paid ra_grp_exp ra_grp_s8 										x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
eststo total_taxes_paid_TOT_5: ivregress2 2sls total_taxes_paid (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv}) first
	addmeans
	local first_stages "`r(first_stages)'"

esttab using ${tabledir}/table12b_tax_13above.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages' CCM_exp CCM_s8 x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*x_f* ) starlevels( ${stars})


****************************************************************************************************************************************************************
****************************************************************************************************************************************************************
*** Appendix
****************************************************************************************************************************************************************
****************************************************************************************************************************************************************

****************************************************************************************************************************************************************
**** Appendix Table 1b - Means of all LHS variables ****
****************************************************************************************************************************************************************

* Load analysis sample, restricting to matched obs
use ./data/mto_work_v5 if intaxdata==1 & mto_kidsample==1 , clear

* Set variables to missing if they do not satisfy our sample restrictions
forval a=24/28{
	gen hh_inc_trim_age`a'  	= hh_inc_trim  if age_outcome==`a'
	gen indv_earn_trim_age`a' 	= indv_earn_trim if age_outcome==`a'
	gen w2wages_trim_age`a'		= w2wages_trim  if age_outcome==`a'
}
foreach v in coll18_x100 coll19_x100 coll20_x100 coll21_x100 coll_qual_18 coll_qual_19 coll_qual_20 coll_qual_21 {
	replace `v' = . if tax_yr!=2012
}
foreach v in worked_x100 indv_earn_growth_5yr poor_share_2000_x100 hhinc_2000 black_share_x100 singlemom_share_x100 filed1040_x100 total_taxes_paid married_x100 {
	replace `v' = . if age_outcome < 24 | !(tax_yr<=2012 & tax_yr>=2008)
}
foreach v in hasbirth_x100 teen_birth_x100 hasbirth_dad_x100 hasbirth_nodad_x100 {
	replace `v' = . if !(gnd_ind=="F" & tax_yr==2012)
}

replace hasbirth_dad_x100 = . if hasbirth!=1
eststo clear
local all_lhs_vars "w2wages_trim_age24 w2wages_trim_age25 w2wages_trim_age26 w2wages_trim_age27 w2wages_trim_age28 indv_earn_trim_age24 indv_earn_trim_age25 indv_earn_trim_age26 indv_earn_trim_age27 indv_earn_trim_age28 hh_inc_trim_age24 hh_inc_trim_age25 hh_inc_trim_age26 hh_inc_trim_age27 hh_inc_trim_age28 worked_x100 indv_earn_growth_5yr coll18_x100 coll19_x100 coll20_x100 coll21_x100 coll_qual_18 coll_qual_19 coll_qual_20 coll_qual_21 hhinc_2000 poor_share_2000_x100 black_share_x100 singlemom_share_x100 married_x100 hasbirth_x100 teen_birth_x100 hasbirth_dad_x100 hasbirth_nodad_x100 filed1040_x100 total_taxes_paid"
estpost summarize `all_lhs_vars' [w=wt_totcore98] , d
esttab using ${tabledir}/app_table1b_lhs_vars_sumstats.csv, cells("mean sd p50 count") replace
esttab , cells("mean sd p50 count") replace

* Calculate number of individuals in sample in a separate table because there is no simple way of incorporating it in the esttab above. This table will be 
*	appended to the table created above to complete app_table_1b
collapse (firstnm) `all_lhs_vars', by(pid)
estpost summarize `all_lhs_vars' 
esttab using ${tabledir}/app_table1b_lhs_vars_sumstats_indiv_counts.csv, cells("count") replace
esttab , cells(" count") replace


****************************************************************************************************************************************************************
**** All x_f Appendix Table 3A: Impact on Income ****
****************************************************************************************************************************************************************

*Load analysis sample, restricting to matched obs
use ./data/mto_work_v5 if intaxdata==1, clear

* Age < 13
global agecond "age_at_ra < 13"
eststo clear
_eststo w2wages_base: 	reg w2wages_trim 			ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 							if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_base: 		reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 							if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_basecon: 	reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 							if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_base_TOT: ivregress2 2sls indv_earn_trim (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* ${x_vars} 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv}) first
	addmeans
	local first_stages "`r(first_stages)'"
_eststo indv_base26: 	reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 							if mto_kidsample == 1  									& age_outcome==26 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_base_2012: reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 							if mto_kidsample == 1 & tax_yr==2012 					& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo work_base: 		reg worked_x100 			ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 							if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hh_base: 		reg hh_inc_trim 			ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 							if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_grth5: 	reg indv_earn_growth_5yr 	ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 							if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans

esttab using ${tabledir}/app_all_xf_table3a_base_below13.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages'  CCM_exp CCM_s8 x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*x_f* ) starlevels( ${stars})

* Age >= 13
global agecond "age_at_ra >= 13"
eststo clear
_eststo w2wages_base: 	reg w2wages_trim 			ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 							if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_base: 		reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 							if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_basecon: 	reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 							if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_base_TOT: ivregress2 2sls indv_earn_trim (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* ${x_vars} 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv}) first
	addmeans
	local first_stages "`r(first_stages)'"
_eststo indv_base26: 	reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 							if mto_kidsample == 1  									& age_outcome==26 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_base_2012: reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 							if mto_kidsample == 1 & tax_yr==2012 					& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo work_base: 		reg worked_x100 			ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 							if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hh_base: 		reg hh_inc_trim 			ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 							if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_grth5: 	reg indv_earn_growth_5yr 	ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 							if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans

esttab using ${tabledir}/app_all_xf_table3b_base_13above.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages'  CCM_exp CCM_s8 x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*x_f* ) starlevels( ${stars})


****************************************************************************************************************************************************************
**** TOT Appendix Table 3B: Impact on Income ****
****************************************************************************************************************************************************************

* Age < 13
global agecond "age_at_ra < 13"
eststo clear
_eststo w2wages_base: 	ivregress 2sls w2wages_trim			(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site*					if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_base: 		ivregress 2sls indv_earn_trim		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site*				 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_basecon: 	ivregress 2sls indv_earn_trim 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* ${x_vars}			if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_base_TOT: ivregress2 2sls indv_earn_trim 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site*					if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv}) first
	addmeans
	local first_stages "`r(first_stages)'"
_eststo indv_base26: 	ivregress 2sls indv_earn_trim 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site*					if mto_kidsample == 1  									& age_outcome==26 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_base_2012: ivregress 2sls indv_earn_trim 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site*					if mto_kidsample == 1 & tax_yr==2012 					& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo work_base: 		ivregress 2sls worked_x100 			(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site*					if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hh_base: 		ivregress 2sls hh_inc_trim 			(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* 					if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_grth5: 	ivregress 2sls indv_earn_growth_5yr (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* 					if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
	local first_stages "`r(first_stages)'"
	
esttab, nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages'  CCM_exp CCM_s8 x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*x_f* ) starlevels( ${stars})
esttab using ${tabledir}/app_tot_table3a_base_below13.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages'  CCM_exp CCM_s8 x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*x_f* ) starlevels( ${stars})

* Age >= 13
global agecond "age_at_ra >= 13"
eststo clear
_eststo w2wages_base: 	ivregress 2sls w2wages_trim				(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site*			if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_base: 		ivregress 2sls indv_earn_trim 			(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site*			if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_basecon: 	ivregress 2sls indv_earn_trim 			(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* ${x_vars}	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_base_TOT: ivregress2 2sls indv_earn_trim 			(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site*			if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv}) first
	addmeans
	local first_stages "`r(first_stages)'"
_eststo indv_base26: 	ivregress 2sls indv_earn_trim 			(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site*			if mto_kidsample == 1  									& age_outcome==26 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_base_2012: ivregress 2sls indv_earn_trim 			(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site*			if mto_kidsample == 1 & tax_yr==2012 					& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo work_base: 		ivregress 2sls worked_x100 				(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site*			if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hh_base: 		ivregress 2sls hh_inc_trim 				(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* 			if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_grth5: 	ivregress 2sls indv_earn_growth_5yr 	(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* 			if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
	local first_stages "`r(first_stages)'"

esttab using ${tabledir}/app_tot_table3b_base_13above.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages'  CCM_exp CCM_s8 x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*x_f* ) starlevels( ${stars})


****************************************************************************************************************************************************************
**** Appendix Table 3C: Income Decomposition ****
****************************************************************************************************************************************************************

* Age < 13
global agecond "age_at_ra < 13"
eststo clear

* check indv_inc = indvearn_inc +ssi+ui
foreach v in w2wages non_w2ssiui indv_earn ssinc uiinc indv_inc indv_inc_spouse hh_inc_trim indv_earn_trim100k hh_inc_trim100k {
	eststo `v': reg `v' ra_grp_exp ra_grp_s8 x_f_site*	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
		addmeans
}

esttab, nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals sample_control_mean) starlevels( ${stars}) drop(x_f_site*)
esttab using ${tabledir}/app_table3C_inc_decomp_below13.csv, nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals sample_control_mean) starlevels( ${stars}) drop(x_f_site*) ///
	addnotes("hh_inc!=indv_inc+indv_inc_spouse because we set negative non-wage (non_w2ssiui) income to 0 before computing indv_inc but not when computing hh_inc")

* Age >= 13
global agecond "age_at_ra >= 13"
eststo clear
foreach v in w2wages non_w2ssiui indv_earn ssinc uiinc indv_inc indv_inc_spouse hh_inc_trim indv_earn_trim100k hh_inc_trim100k {
	eststo `v': reg `v' ra_grp_exp ra_grp_s8 x_f_site*	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
		addmeans
}

esttab, nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals sample_control_mean) starlevels( ${stars}) drop(x_f_site*)
esttab using ${tabledir}/app_table3C_inc_decomp_13above.csv, nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals sample_control_mean) starlevels( ${stars}) drop(x_f_site*) ///
	addnotes("hh_inc!=indv_inc+indv_inc_spouse because we set negative non-wage (non_w2ssiui) income to 0 before computing indv_inc but not when computing hh_inc")


****************************************************************************************************************************************************************
**** All x_f Appendix Table 4A: Impact on College and College Quality ****
****************************************************************************************************************************************************************

* Age < 13
global agecond "age_at_ra<13"
eststo clear
_eststo coll_pool_1820:	reg coll_pool_1820_x100	ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond}  				[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll18: 		reg coll18_x100 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll19: 		reg coll19_x100 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll20: 		reg coll20_x100 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll21: 		reg coll21_x100 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820: 		reg coll_qual_pool_1820 ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond}  				[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq18: 			reg coll_qual_18 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq19: 			reg coll_qual_19 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq20: 			reg coll_qual_20 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq21: 			reg coll_qual_21 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
	
esttab using ${tabledir}/app_all_xf_table4a_coll_below13.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(x_f*) starlevels( ${stars})
	
* Age >= 13
global agecond "age_at_ra>=13"
eststo clear
_eststo coll_pool_1820:	reg coll_pool_1820_x100	ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond}  				[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll18: 		reg coll18_x100 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll19: 		reg coll19_x100 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll20: 		reg coll20_x100 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll21: 		reg coll21_x100 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820: 		reg coll_qual_pool_1820 ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond}			 		[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq18: 			reg coll_qual_18 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq19: 			reg coll_qual_19 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq20: 			reg coll_qual_20 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq21: 			reg coll_qual_21 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
	
esttab using ${tabledir}/app_all_xf_table4b_coll_13above.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(x_f*) starlevels( ${stars})

	
****************************************************************************************************************************************************************
**** TOT Appendix Table 4B: Impact on College and College Quality ****
****************************************************************************************************************************************************************

* Age < 13
global agecond "age_at_ra<13"
eststo clear
_eststo coll_pool_1820:	ivregress2 2sls coll_pool_1820_x100 (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond}  				[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll18: 		ivregress2 2sls coll18_x100 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll19: 		ivregress2 2sls coll19_x100 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll20: 		ivregress2 2sls coll20_x100 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll21: 		ivregress2 2sls coll21_x100 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820: 		ivregress2 2sls coll_qual_pool_1820 (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond}				[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq18: 			ivregress2 2sls coll_qual_18 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq19: 			ivregress2 2sls coll_qual_19 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq20: 			ivregress2 2sls coll_qual_20 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq21: 			ivregress2 2sls coll_qual_21 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans	
	local first_stages "`r(first_stages)'"
	
esttab using ${tabledir}/app_tot_table4a_coll_below13.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages'  CCM_exp CCM_s8 x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(x_f*) starlevels( ${stars})
		
* Age >= 13
global agecond "age_at_ra>=13"
eststo clear
_eststo coll_pool_1820:	ivregress2 2sls coll_pool_1820_x100 (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond}  				[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll18: 		ivregress2 2sls coll18_x100 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll19: 		ivregress2 2sls coll19_x100 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll20: 		ivregress2 2sls coll20_x100 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll21: 		ivregress2 2sls coll21_x100 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820: 		ivregress2 2sls coll_qual_pool_1820 (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond} 				[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq18: 			ivregress2 2sls coll_qual_18 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq19: 			ivregress2 2sls coll_qual_19 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq20: 			ivregress2 2sls coll_qual_20 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq21: 			ivregress2 2sls coll_qual_21 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans	
	local first_stages "`r(first_stages)'"
	
esttab using ${tabledir}/app_tot_table4b_coll_13above.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages'  CCM_exp CCM_s8 x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(x_f*) starlevels( ${stars})


****************************************************************************************************************************************************************
**** All x_f Appendix Table 5A: Impacts on Fertility ****
****************************************************************************************************************************************************************

* Age < 13
global agecond "age_at_ra<13"
eststo clear
_eststo married: 		reg married_x100 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & (tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24	& ${agecond} 				 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_m: 		reg married_x100		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & (tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24	& ${agecond} & gnd_ind=="M" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_f: 		reg married_x100		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & (tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24	& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo anybirth: 		reg hasbirth_x100 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=21  					& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo teenbirth: 		reg teen_birth_x100 	ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=21  					& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hasbirth_dad: 	reg hasbirth_dad_x100 	ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=21 & hasbirth==1		& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hasbirth_nodad: reg hasbirth_nodad_x100	ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=21   					& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
	
esttab , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals exp_exp_same_p x_f_controls Sample sample_control_mean, fmt(0 4 1)) unstack drop(x_f_site* ${x_vars} ) starlevels( ${stars})
esttab using ${tabledir}/app_all_xf_table5a_teenbirth_below13.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals exp_exp_same_p x_f_controls Sample sample_control_mean, fmt(0 4 1)) unstack drop(x_f_site* ${x_vars} ) starlevels( ${stars})

* Age >= 13
global agecond "age_at_ra>=13"
eststo clear
_eststo married: 		reg married_x100 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & (tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24	& ${agecond} 				 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_m: 		reg married_x100		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & (tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24	& ${agecond} & gnd_ind=="M" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_f: 		reg married_x100		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & (tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24	& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo anybirth: 		reg hasbirth_x100 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=21  					& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo teenbirth: 		reg teen_birth_x100 	ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=21  					& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hasbirth_dad: 	reg hasbirth_dad_x100 	ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=21 & hasbirth==1		& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hasbirth_nodad: reg hasbirth_nodad_x100	ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=21   					& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
	
local x_vars_kids_drop "x_f_C1* age_at_ra x_f_Ch_male x_f_Ch_schplay x_f_Ch_specmed x_f_Ch_schplay_miss" // x_f_C2 vars all dropped for collinearity in this spec"
esttab , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals exp_exp_same_p x_f_controls Sample sample_control_mean, fmt(0 4 1)) unstack drop(x_f_site* ${x_vars}) starlevels( ${stars})
esttab using ${tabledir}/app_all_xf_table5b_teenbirth_13above.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals exp_exp_same_p x_f_controls Sample sample_control_mean, fmt(0 4 1)) unstack drop(x_f_site* ${x_vars} ) starlevels( ${stars})


****************************************************************************************************************************************************************
**** TOT Appendix Table 5B: Impacts on Fertility ****
****************************************************************************************************************************************************************

* Age < 13

global agecond "age_at_ra<13"
eststo clear
_eststo married: 		ivregress2 2sls married_x100 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & (tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24	& ${agecond} 				 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_m: 		ivregress2 2sls married_x100		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & (tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24	& ${agecond} & gnd_ind=="M" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_f: 		ivregress2 2sls married_x100		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & (tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24	& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo anybirth: 		ivregress2 2sls hasbirth_x100 	  	(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=21  					& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo teenbirth: 		ivregress2 2sls teen_birth_x100   	(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=21  					& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hasbirth_dad: 	ivregress2 2sls hasbirth_dad_x100 	(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=21 & hasbirth==1		& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hasbirth_nodad: ivregress2 2sls hasbirth_nodad_x100 (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=21   					& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
	local first_stages "`r(first_stages)'"
	
esttab using ${tabledir}/app_tot_table5a_teenbirth_below13.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals `first_stages'  CCM_exp CCM_s8 exp_exp_same_p x_f_controls Sample sample_control_mean, fmt(0 4 1)) unstack drop(x_f_site* ) starlevels( ${stars})

* Age >= 13
global agecond "age_at_ra>=13"
eststo clear
_eststo married: 		ivregress2 2sls married_x100 		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & (tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24	& ${agecond} 				 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_m: 		ivregress2 2sls married_x100		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & (tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24	& ${agecond} & gnd_ind=="M" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_f: 		ivregress2 2sls married_x100		(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & (tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24	& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo anybirth: 		ivregress2 2sls hasbirth_x100 	  	(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=21  					& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo teenbirth: 		ivregress2 2sls teen_birth_x100   	(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=21  					& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hasbirth_dad: 	ivregress2 2sls hasbirth_dad_x100 	(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=21 & hasbirth==1		& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hasbirth_nodad: ivregress2 2sls hasbirth_nodad_x100 (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=21   					& ${agecond} & gnd_ind=="F" [w=wt_totcore98], cluster(${cv})
	addmeans
	local first_stages "`r(first_stages)'"
	
esttab using ${tabledir}/app_tot_table5b_teenbirth_13above.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals `first_stages'  CCM_exp CCM_s8 exp_exp_same_p x_f_controls Sample sample_control_mean, fmt(0 4 1)) unstack drop(x_f_site* ) starlevels( ${stars})

	
****************************************************************************************************************************************************************
**** All x_f Appendix Table 6A - Impact on Neighborhood characteristics ****
****************************************************************************************************************************************************************

* Age < 13
global agecond "age_at_ra < 13"						
eststo clear
_eststo poor_share_5: 		reg poor_share_2000_x100 	ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans	
_eststo hhinc_5: 			reg hhinc_2000 				ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo black_share_5: 		reg black_share_x100 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo singlemom_share: 	reg singlemom_share_x100  	ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans

esttab using ${tabledir}/app_all_xf_table6a_nbhd_firm_below13.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3)))  stats(N num_individuals x_f_controls Sample sample_control_mean, fmt(0 0 1)) drop(x_f*) starlevels( ${stars})

* Age >= 13	
global agecond "age_at_ra>=13"						
eststo clear
_eststo poor_share_5: 		reg poor_share_2000_x100 	ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans	
_eststo hhinc_5: 			reg hhinc_2000 				ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo black_share_5: 		reg black_share_x100 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo singlemom_share: 	reg singlemom_share_x100  	ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans

esttab using ${tabledir}/app_all_xf_table6b_nbhd_firm_13above.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3)))  stats(N num_individuals x_f_controls Sample sample_control_mean, fmt(0 0 1)) drop(x_f*) starlevels( ${stars})


****************************************************************************************************************************************************************
**** TOT Appendix Table 6B - Neighborhood characteristics ****
****************************************************************************************************************************************************************

* Age < 13
global agecond "age_at_ra < 13"						
eststo clear
_eststo poor_share_5: 		ivregress2 2sls poor_share_2000_x100 (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hhinc_5: 			ivregress2 2sls hhinc_2000 			 (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo black_share_5: 		ivregress2 2sls black_share_x100	 (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo singlemom_share: 	ivregress2 2sls singlemom_share_x100 (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
	local first_stages "`r(first_stages)'"

esttab using ${tabledir}/app_tot_table6a_nbhd_firm_below13.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3)))  stats(N num_individuals `first_stages'  CCM_exp CCM_s8 x_f_controls Sample sample_control_mean, fmt(0 0 1)) drop(x_f_site*) starlevels( ${stars})

* Age >= 13
global agecond "age_at_ra>=13"						
eststo clear
_eststo poor_share_5: 		ivregress2 2sls poor_share_2000_x100 (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hhinc_5: 			ivregress2 2sls hhinc_2000 			 (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo black_share_5: 		ivregress2 2sls black_share_x100	 (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo singlemom_share: 	ivregress2 2sls singlemom_share_x100 (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
	local first_stages "`r(first_stages)'"

esttab using ${tabledir}/app_tot_table6b_nbhd_firm_13above.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3)))  stats(N num_individuals `first_stages'  CCM_exp CCM_s8 x_f_controls Sample sample_control_mean, fmt(0 0 1)) drop(x_f_site*) starlevels( ${stars})


****************************************************************************************************************************************************************
**** Appendix Table 7A - Heterogeneity by Race 
****************************************************************************************************************************************************************

* Age < 13
global agecond "age_at_ra < 13"

*  Race - Hispanic
eststo clear
_eststo indv_base_h: 		reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& ${agecond} & x_f_Ad_ethn_hisp == 1	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820_h: 			reg coll_qual_pool_1820 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 				 									& ${agecond} & x_f_Ad_ethn_hisp == 1	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_h: 			reg married_x100			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& ${agecond} & x_f_Ad_ethn_hisp == 1	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo poor_share_2000_h: 	reg poor_share_2000_x100 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012										& ${agecond} & x_f_Ad_ethn_hisp == 1 	[w=wt_totcore98], cluster(${cv})
	addmeans

esttab using ${tabledir}/app_table7Aa_below13_hisp.csv, nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals x_f_controls Sample sample_control_mean, fmt(0 0 1)) unstack drop(x_f_site*) starlevels( ${stars})

*  Race - Not black, not Hispanic
eststo clear
_eststo indv_base_nb_nh: 		reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& ${agecond} & x_f_Ad_ethn_hisp == 0 & x_f_Ad_race_black == 0 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820_nb_nh: 			reg coll_qual_pool_1820 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 													& ${agecond} & x_f_Ad_ethn_hisp == 0 & x_f_Ad_race_black == 0 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_nb_nh: 			reg married_x100			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& ${agecond} & x_f_Ad_ethn_hisp == 0 & x_f_Ad_race_black == 0	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo poor_share_2000_nb_nh: 	reg poor_share_2000_x100 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012										& ${agecond} & x_f_Ad_ethn_hisp == 0 & x_f_Ad_race_black == 0 	[w=wt_totcore98], cluster(${cv})
	addmeans
	
esttab using ${tabledir}/app_table7Aa_below13_nhisp_nblack.csv, nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals x_f_controls Sample sample_control_mean, fmt(0 0 1)) unstack drop(x_f_site*) starlevels( ${stars})
	
*  Race - Black, non-Hispanic
eststo clear	
_eststo indv_base_b_nh: 		reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24	& ${agecond} & x_f_Ad_ethn_hisp == 0 & x_f_Ad_race_black == 1	[w=wt_totcore98], cluster(${cv})
	addmeans	
_eststo kcq1820_b_nh: 			reg coll_qual_pool_1820 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 				 									& ${agecond} & x_f_Ad_ethn_hisp == 0 & x_f_Ad_race_black == 1	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_b_nh: 			reg married_x100			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& ${agecond} & x_f_Ad_ethn_hisp == 0 & x_f_Ad_race_black == 1	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo poor_share_2000_b_nh: 	reg poor_share_2000_x100 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012 									& ${agecond} & x_f_Ad_ethn_hisp == 0 & x_f_Ad_race_black == 1	[w=wt_totcore98], cluster(${cv})
	addmeans
	
esttab using ${tabledir}/app_table7Aa_below13_black_nhisp.csv, nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals x_f_controls Sample sample_control_mean, fmt(0 0 1)) unstack drop(x_f_site*) starlevels( ${stars})
	
* Age >= 13
global agecond "age_at_ra >= 13"

*  Race - Hispanic
eststo clear
_eststo indv_base_h: 		reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24	& ${agecond} & x_f_Ad_ethn_hisp == 1	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820_h: 			reg coll_qual_pool_1820 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 													& ${agecond} & x_f_Ad_ethn_hisp == 1 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_h: 			reg married_x100			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& ${agecond} & x_f_Ad_ethn_hisp == 1	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo poor_share_2000_h: 	reg poor_share_2000_x100 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012 									& ${agecond} & x_f_Ad_ethn_hisp == 1	[w=wt_totcore98], cluster(${cv})
	addmeans

esttab using ${tabledir}/app_table7Ab_13above_hisp.csv ,nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals x_f_controls Sample sample_control_mean, fmt(0 0 1)) unstack drop(x_f_site*) starlevels( ${stars})

*  Race - Not black, not Hispanic
eststo clear
_eststo indv_base_nb_nh: 		reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& ${agecond} & x_f_Ad_ethn_hisp == 0 & x_f_Ad_race_black == 0 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820_nb_nh: 			reg coll_qual_pool_1820 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 													& ${agecond} & x_f_Ad_ethn_hisp == 0 & x_f_Ad_race_black == 0	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_nb_nh: 			reg married_x100			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& ${agecond} & x_f_Ad_ethn_hisp == 0 & x_f_Ad_race_black == 0	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo poor_share_2000_nb_nh: 	reg poor_share_2000_x100 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012										& ${agecond} & x_f_Ad_ethn_hisp == 0 & x_f_Ad_race_black == 0	[w=wt_totcore98], cluster(${cv})
	addmeans
	
esttab using ${tabledir}/app_table7Ab_13above_nhisp_nblack.csv ,nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals x_f_controls Sample sample_control_mean, fmt(0 0 1)) unstack drop(x_f_site*) starlevels( ${stars})
	
*  Race - Black, non-Hispanic
eststo clear	
_eststo indv_base_b_nh: 		reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24	& ${agecond} & x_f_Ad_ethn_hisp == 0 & x_f_Ad_race_black == 1	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820_b_nh: 			reg coll_qual_pool_1820 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 													& ${agecond} & x_f_Ad_ethn_hisp == 0 & x_f_Ad_race_black == 1	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_b_nh: 			reg married_x100			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& ${agecond} & x_f_Ad_ethn_hisp == 0 & x_f_Ad_race_black == 1	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo poor_share_2000_b_nh: 	reg poor_share_2000_x100 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012  									& ${agecond} & x_f_Ad_ethn_hisp == 0 & x_f_Ad_race_black == 1	[w=wt_totcore98], cluster(${cv})
	addmeans
	
esttab using ${tabledir}/app_table7Ab_13above_black_nhisp.csv ,nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals x_f_controls Sample sample_control_mean, fmt(0 0 1)) unstack drop(x_f_site*) starlevels( ${stars})
	

****************************************************************************************************************************************************************
**** Appendix Table 7B - Heterogeneity by site ****
****************************************************************************************************************************************************************

* Age < 13
global agecond "age_at_ra < 13"
eststo clear
forval s = 1(1)5 {

_eststo indv_base_s`s': 		reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& ${agecond} & ra_site == `s' 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820_s`s': 			reg coll_qual_pool_1820 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 													& ${agecond} & ra_site == `s' 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_s`s': 			reg married_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& ${agecond} & ra_site == `s' 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo poor_share_2000_s`s': 	reg poor_share_2000_x100 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012 									& ${agecond} & ra_site == `s' 	[w=wt_totcore98], cluster(${cv})
	addmeans
}

esttab using ${tabledir}/app_table7Ba_below13_site.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals x_f_controls Sample sample_control_mean, fmt(0 0 1)) unstack drop(x_f_site*) starlevels( ${stars})

* Age >= 13
global agecond "age_at_ra >= 13"
eststo clear
forval s = 1(1)5 {

_eststo indv_base_s`s': 		reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 &	(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24	& ${agecond} & ra_site == `s' 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820_s`s': 			reg coll_qual_pool_1820 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 													& ${agecond} & ra_site == `s' 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_s`s':	 		reg married_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & (tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& ${agecond} & ra_site == `s'	[w=wt_totcore98], cluster(${cv})
	addmeans	
_eststo poor_share_2000_s`s': 	reg poor_share_2000_x100 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012 									& ${agecond} & ra_site == `s' 	[w=wt_totcore98], cluster(${cv})
	addmeans
}

esttab using ${tabledir}/app_table7Bb_13above_site.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stat(N num_individuals x_f_controls Sample sample_control_mean, fmt(0 0 1)) unstack drop(x_f_site*) starlevels( ${stars})


****************************************************************************************************************************************************************
**** All x_f Appendix Table 8A: Exposure Time Linear Models for Kids ****
****************************************************************************************************************************************************************

eststo clear
_eststo exp_indv_earn: 			reg indv_earn_trim 			ra_grp_exp ra_grp_s8 age_exp age_s8 									${age_controls} ${x_vars} 	if mto_kidsample==1 &(tax_yr<=2012 & tax_yr>=2008)	& age_outcome>=24 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo exp_hh_inc: 			reg hh_inc_trim 			ra_grp_exp ra_grp_s8 age_exp age_s8 									${age_controls} ${x_vars} 	if mto_kidsample==1 &(tax_yr<=2012 & tax_yr>=2008)	& age_outcome>=24 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo exp_hh_inc26: 			reg hh_inc_trim 			ra_grp_exp ra_grp_s8 age_exp age_s8 									${age_controls} ${x_vars} 	if mto_kidsample==1 								& age_outcome==26 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo exp_collqual1820: 		reg coll_qual_pool_1820 	ra_grp_exp age_exp ra_grp_s8 age_s8 									${age_controls} ${x_vars} 	if mto_kidsample==1		 												[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married: 				reg married_x100			ra_grp_exp age_exp ra_grp_s8 age_s8 									${age_controls} ${x_vars}	if mto_kidsample==1 &(tax_yr<=2012 & tax_yr>=2008)	& age_outcome>=24	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo exp_poor_share_2000: 	reg poor_share_2000_x100 	ra_grp_exp age_exp ra_grp_s8 age_s8 									${age_controls} ${x_vars} 	if mto_kidsample==1 &(tax_yr<=2012 & tax_yr>=2008)	& age_outcome>=24 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo exp_tot_taxes: 			reg total_taxes_paid 		ra_grp_exp ra_grp_s8 age_exp age_s8 									${age_controls} ${x_vars} 	if mto_kidsample==1 &(tax_yr<=2012 & tax_yr>=2008)	& age_outcome>=24 	[w=wt_totcore98], cluster(${cv})
	addmeans
	
esttab  , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals  `first_stages'  x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*age_at_ra_kids* ${x_vars}) starlevels( ${stars})
esttab using ${tabledir}/app_all_xf_table8_exposure.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages' x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*age_at_ra_kids* ${x_vars}) starlevels( ${stars})


****************************************************************************************************************************************************************
**** TOT Appendix Table 8B: Exposure Time Linear Models for Kids ****
****************************************************************************************************************************************************************

eststo clear
_eststo exp_indv_earn: 			ivregress2 2sls indv_earn_trim 			(cmove_exp cmove_s8 age_cmove_exp age_cmove_s8 = ra_grp_exp ra_grp_s8 age_exp age_s8) ${age_controls} if mto_kidsample==1 &(tax_yr<=2012 & tax_yr>=2008)& age_outcome>=24 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo exp_hh_inc: 			ivregress2 2sls hh_inc_trim 			(cmove_exp cmove_s8 age_cmove_exp age_cmove_s8 = ra_grp_exp ra_grp_s8 age_exp age_s8) ${age_controls} if mto_kidsample==1 &(tax_yr<=2012 & tax_yr>=2008)& age_outcome>=24	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo exp_hh_inc26: 			ivregress2 2sls hh_inc_trim 			(cmove_exp cmove_s8 age_cmove_exp age_cmove_s8 = ra_grp_exp ra_grp_s8 age_exp age_s8) ${age_controls} if mto_kidsample==1 								& age_outcome==26 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo exp_collqual1820:		ivregress2 2sls coll_qual_pool_1820 	(cmove_exp cmove_s8 age_cmove_exp age_cmove_s8 = ra_grp_exp ra_grp_s8 age_exp age_s8) ${age_controls} if mto_kidsample==1 										 			[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo exp_married: 			ivregress2 2sls married_x100 			(cmove_exp cmove_s8 age_cmove_exp age_cmove_s8 = ra_grp_exp ra_grp_s8 age_exp age_s8) ${age_controls} if mto_kidsample==1 &(tax_yr<=2012 & tax_yr>=2008)& age_outcome>=24 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo exp_poor_share_2000: 	ivregress2 2sls poor_share_2000_x100 	(cmove_exp cmove_s8 age_cmove_exp age_cmove_s8 = ra_grp_exp ra_grp_s8 age_exp age_s8) ${age_controls} if mto_kidsample==1 &(tax_yr<=2012 & tax_yr>=2008)& age_outcome>=24 	[w=wt_totcore98], cluster(${cv})
	addmeans
_eststo exp_tot_taxes: 			ivregress2 2sls total_taxes_paid 		(cmove_exp cmove_s8 age_cmove_exp age_cmove_s8 = ra_grp_exp ra_grp_s8 age_exp age_s8) ${age_controls} if mto_kidsample==1 &(tax_yr<=2012 & tax_yr>=2008)& age_outcome>=24 	[w=wt_totcore98], cluster(${cv})
	addmeans
	local first_stages "`r(first_stages)'"
	
esttab  , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals  `first_stages'  x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*age_at_ra_kids* ) starlevels( ${stars})
esttab using ${tabledir}/app_tot_table8_exposure.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages' x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*age_at_ra_kids* ) starlevels( ${stars})


****************************************************************************************************************************************************************
**** All x_f Appendix Table 9A: Income Outcomes for Adults ****
****************************************************************************************************************************************************************

eststo clear
_eststo indv_earn5: 	reg indv_earn_trim 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_adultsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_earn5con: 	reg indv_earn_trim 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_adultsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_earn2012: 	reg indv_earn_trim 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_adultsample == 1 & tax_yr==2012 				& age_outcome>=24 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hh_inc5: 		reg hh_inc_trim 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_adultsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo worked5: 		reg worked_x100 		ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_adultsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 [w=wt_totcore98], cluster(${cv})
	addmeans
	
esttab using ${tabledir}/app_all_xf_table9_adult.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(x_f_site* ${x_vars} ) starlevels( ${stars})


****************************************************************************************************************************************************************
**** TOT Appendix Table 9B: Income Outcomes for Adults ****
****************************************************************************************************************************************************************

eststo clear
_eststo indv_earn5: 	ivregress2 2sls indv_earn_trim 			(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* 			if mto_adultsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_earn5con: 	ivregress2 2sls indv_earn_trim 			(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* ${x_vars} if mto_adultsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo indv_earn2012: 	ivregress2 2sls indv_earn_trim 			(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* 			if mto_adultsample == 1 & tax_yr==2012 					& age_outcome>=24 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo hh_inc5: 		ivregress2 2sls hh_inc_trim 			(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* 			if mto_adultsample == 1 &(tax_yr<=2012 & tax_yr>=2008)	& age_outcome>=24 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo worked5: 		ivregress2 2sls worked_x100 			(cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* 			if mto_adultsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 [w=wt_totcore98], cluster(${cv})
	addmeans
	local first_stages "`r(first_stages)'"
	
esttab using ${tabledir}/app_tot_table9_adult.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages'  CCM_exp CCM_s8 x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(x_f*) starlevels( ${stars})


****************************************************************************************************************************************************************
**** All x_f Appendix Table 10A: Tax Revenue ****
****************************************************************************************************************************************************************

use ./data/mto_work_v5 if intaxdata==1, clear      

* Age < 13
eststo clear
global agecond "age_at_ra<13"
eststo filed1040_5: 			reg filed1040_x100 ra_grp_exp ra_grp_s8 									x_f_site* ${x_vars} if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
eststo total_taxes_paid_5: 		reg total_taxes_paid ra_grp_exp ra_grp_s8 									x_f_site* ${x_vars} if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
eststo total_taxes_paid_TOT_5: ivregress2 2sls total_taxes_paid (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* ${x_vars} if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv}) first
	addmeans
	local first_stages "`r(first_stages)'"

esttab using ${tabledir}/app_all_xf_table10a_tax_below13.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages' CCM_exp CCM_s8 x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*x_f* ) starlevels( ${stars})

* Age >= 13
eststo clear
global agecond "age_at_ra>=13"
eststo filed1040_5: 			reg filed1040_x100 ra_grp_exp ra_grp_s8 									x_f_site* ${x_vars} if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
eststo total_taxes_paid_5: 		reg total_taxes_paid ra_grp_exp ra_grp_s8 									x_f_site* ${x_vars} if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
eststo total_taxes_paid_TOT_5: ivregress2 2sls total_taxes_paid (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) x_f_site* ${x_vars} if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & ${agecond} [w=wt_totcore98], cluster(${cv}) first
	addmeans
	local first_stages "`r(first_stages)'"

esttab using ${tabledir}/app_all_xf_table10b_tax_13above.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages' CCM_exp CCM_s8 x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*x_f* ) starlevels( ${stars})


****************************************************************************************************************************************************************
**** TOT Appendix Table 10B - Tax Revenue ***
****************************************************************************************************************************************************************

* Age < 13
global agecond "age_at_ra<13"
eststo clear
eststo filed1040_5: 			ivregress2 2sls filed1040_x100 	 (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) 	x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008)	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
eststo total_taxes_paid_5: 		ivregress2 2sls total_taxes_paid (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8)	x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans	
eststo total_taxes_paid_TOT_5: 	ivregress2 2sls total_taxes_paid (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8)	x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv}) first
	addmeans
	local first_stages "`r(first_stages)'"

esttab using ${tabledir}/app_tot_table10a_tax_below13.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages' CCM_exp CCM_s8 x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*x_f* ) starlevels( ${stars})

* Age >= 13
global agecond "age_at_ra>=13"
eststo clear
eststo filed1040_5: 			ivregress2 2sls filed1040_x100 	 (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8) 	x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008)	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
eststo total_taxes_paid_5: 		ivregress2 2sls total_taxes_paid (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8)	x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans	
eststo total_taxes_paid_TOT_5: 	ivregress2 2sls total_taxes_paid (cmove_exp cmove_s8 = ra_grp_exp ra_grp_s8)	x_f_site* if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv}) first
	addmeans
	local first_stages "`r(first_stages)'"

esttab using ${tabledir}/app_tot_table10b_tax_13above.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals `first_stages' CCM_exp CCM_s8 x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(*x_f* ) starlevels( ${stars})


****************************************************************************************************************************************************************
**** Appendix Table 11: Robustness to various age cutoffs ****
****************************************************************************************************************************************************************

gen treat = ra_grp_exp==1 | ra_grp_s8==1

eststo clear
forval a=12/14{ 

global agecond "age_at_ra<`a'"	
_eststo kinc_base_b`a': 	reg indv_earn_trim 			ra_grp_exp ra_grp_s8 x_f_site*	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo cq_pool_1820_b`a':	reg coll_qual_pool_1820   	ra_grp_exp ra_grp_s8 x_f_site*	if mto_kidsample == 1 														& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_b`a': 		reg married_x100 			ra_grp_exp ra_grp_s8 x_f_site*	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo poor_share_5_b`a': 	reg poor_share_2000_x100 	ra_grp_exp ra_grp_s8 x_f_site*	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
eststo tot_taxes_5_b`a':	reg total_taxes_paid 		ra_grp_exp ra_grp_s8 x_f_site*	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
}	

global agecond "age_at_ra<13"	
_eststo kinc_base_treat: 	reg indv_earn_trim 			treat x_f_site*	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo cq_pool_1820_treat:	reg coll_qual_pool_1820   	treat x_f_site*	if mto_kidsample == 1 														& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_treat: 		reg married_x100 			treat x_f_site*	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo poor_share_5_treat: reg poor_share_2000_x100 	treat x_f_site*	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
eststo tot_taxes_treat:		reg total_taxes_paid 		treat x_f_site*	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kinc_base_treat_con: 	reg indv_earn_trim 			treat x_f_site* ${x_vars}	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo cq_pool_1820_treat_con:	reg coll_qual_pool_1820   	treat x_f_site* ${x_vars}	if mto_kidsample == 1 														& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo married_treat_con: 		reg married_x100 			treat x_f_site* ${x_vars}	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo poor_share_treat_con: 	reg poor_share_2000_x100 	treat x_f_site* ${x_vars}	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
eststo tot_taxes_5_treat_con:	reg total_taxes_paid 		treat x_f_site* ${x_vars} 	if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 	& ${agecond} [w=wt_totcore98], cluster(${cv})
	addmeans
	
esttab using ${tabledir}/app_table11_robust_age_cutoff_below_base.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals , fmt(0 0 )) drop(*x_f* ) starlevels( ${stars})
esttab, nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals , fmt(0 0 )) drop(*x_f* ) starlevels( ${stars})


****************************************************************************************************************************************************************
****************************************************************************************************************************************************************
*** Figures
****************************************************************************************************************************************************************
****************************************************************************************************************************************************************

use ./data/mto_work_v5 if intaxdata==1, clear     

****************************************************************************************************************************************************************
**** Figure 1 and Appendix Figure 1: Impacts by age of measurement ****
****************************************************************************************************************************************************************

eststo clear
forval i=20/28{
	_eststo indv_earnings_age_`i'_b13: reg indv_earn_trim ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & age_outcome==`i' & age_at_ra < 13 [w=wt_totcore98], cluster(${cv})
	addmeans
	_eststo indv_earnings_age_`i'_13a: reg indv_earn_trim ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & age_outcome==`i' & age_at_ra >=13 [w=wt_totcore98], cluster(${cv})
	addmeans
}

esttab indv_earnings_age_*b13, replace nodepvar cells(b ci_l ci_u) keep(ra_grp_exp ra_grp_s8) stat(N sample_control_mean) nonumbers nomtitles
esttab indv_earnings_age_*b13 using ${tabledir}/figure1a_below13.csv, replace nodepvar cells(b ci_l ci_u) keep(ra_grp_exp ra_grp_s8) stat(N sample_control_mean) nonumbers
esttab indv_earnings_age_*b13 using ${tabledir}/app_table13_figure1a_below13.csv, replace nodepvar cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) keep(ra_grp_exp ra_grp_s8) stat(N sample_control_mean) nonumbers starlevels( ${stars})

esttab indv_earnings_age_*13a, replace nodepvar cells(b ci_l ci_u) keep(ra_grp_exp ra_grp_s8) stat(N sample_control_mean) nonumbers
esttab indv_earnings_age_*13a using ${tabledir}/figure1b_13above.csv, replace nodepvar cells(b ci_l ci_u) keep(ra_grp_exp ra_grp_s8) stat(N sample_control_mean) nonumbers
esttab indv_earnings_age_*13a using ${tabledir}/app_table13_figure1b_13above.csv, replace nodepvar cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) keep(ra_grp_exp ra_grp_s8) stat(N sample_control_mean) nonumbers starlevels( ${stars})


****************************************************************************************************************************************************************
**** Figure 2 and Appendix Figure 2: Impacts by children's age at RA ****
****************************************************************************************************************************************************************

* Household Income Exposure Graph
* A) Create age bins
cap drop age_bin_inc
g age_bin_inc = int(age_at_ra/2)*2
replace age_bin_inc = 10 if age_bin<10
replace age_bin_inc = 16 if age_bin>16

* B) FIGURE 2A
* Run the reg for each age bin in a loop
eststo clear
forval a = 10(2)16 {
	eststo agebin`a': qui reg hh_inc_trim ra_grp_exp ra_grp_s8 x_f_site* if (tax_yr<=2012 & tax_yr>=2008)	& age_outcome>=24 & age_bin_inc==`a'&mto_kidsample==1 [w=wt_totcore98], cluster(${cv})
	su age_at_ra if e(sample) [w=wt_totcore98]
	local mean_age = `r(mean)'
	estadd scalar mean_age_in_bin = `mean_age'
}

esttab using ${tabledir}/figure2a_inc_exp.csv, 		replace keep(ra_grp_exp) cells(b se) stats(N mean_age) nodepvar
esttab using ${tabledir}/app_figure2a_inc_s8.csv,	replace keep(ra_grp_s8)  cells(b se) stats(N mean_age) nodepvar

* College Quality Exposure Graph
* A) Create age bins
cap drop age_bin
g age_bin = int(age_at_ra/2)*2
replace age_bin = 4 if age_bin<4
replace age_bin = 16 if age_bin>16

* B) FIGURE 2B 
* Run the reg for each age bin in a loop
eststo clear
forval a = 4(2)16 {
	eststo agebin`a': qui reg coll_qual_pool_1820 ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample==1&age_bin==`a'  [w=wt_totcore98], cluster(${cv})
	su age_at_ra if e(sample) [w=wt_totcore98]
	local mean_age = `r(mean)'
	estadd scalar mean_age_in_bin = `mean_age'
}

esttab using ${tabledir}/figure2b_cq_exp.csv, 		replace keep(ra_grp_exp) cells(b se) stats(N mean_age) nodepvar
esttab using ${tabledir}/app_figure2b_cq_s8.csv,	replace keep(ra_grp_s8)  cells(b se) stats(N mean_age) nodepvar


****************************************************************************************************************************************************************
**** Figure 3 and Appendix Figure 3: Impacts on Adults ****
****************************************************************************************************************************************************************

gen ra_year = year(ra_date)
gen yrs_since_ra = tax_yr - ra_year
drop if yrs_since_ra == 0
gen yrsbin = 2*floor((1+yrs_since_ra )/2)

eststo clear
forval a=2(2)10{
	di `a'
	eststo yrsbin`a':  reg indv_earn ra_grp_exp ra_grp_s8 x_f_site* if mto_adultsample==1 & age_outcome>=24 & yrsbin==`a'	  [w=wt_totcore98], cluster(${cv})
}	

esttab using ${tabledir}/app_figure3.csv, 	replace keep(ra_grp_exp ra_grp_s8) cells(b se) stats(N mean_age) nodepvar
 

****************************************************************************************************************************************************************
****************************************************************************************************************************************************************
*** Text Notes and Robustness Checks
****************************************************************************************************************************************************************
****************************************************************************************************************************************************************

global agecond "age_at_ra<13"	

log using ${tabledir}/mto_text_notes.smcl, replace

use ./data/mto_work_v5 if intaxdata==1, clear

* 1 Compare age at RA for those above vs below age 13

* Full sample of all kids linked to tax data [essentially identical to Table 2 estimates from MTO data, so can just use those estimates]
su age_at_ra if mto_kidsample==1&tax_yr==2012&age_at_ra<13
su age_at_ra if mto_kidsample==1&tax_yr==2012&age_at_ra>=13

* College sample is identical
su age_at_ra if mto_kidsample==1&tax_yr==2012&age_at_ra<13&coll_qual_pool_1820~=.
su age_at_ra if mto_kidsample==1&tax_yr==2012&age_at_ra>=13&coll_qual_pool_1820~=.

* Income at 26 sample
su age_at_ra if mto_kidsample==1&age_at_ra<13&age_outcome==26
su age_at_ra if mto_kidsample==1&age_at_ra>=13&age_outcome==26

cap g below13 = age_at_ra<13 if mto_kidsample==1

* Income
xi: reg indv_earn_trim i.below13*ra_grp_exp i.below13*ra_grp_s8 below13#(x_f_site*) if mto_kidsample==1 &(tax_yr<=2012 & tax_yr>=2008)&age_outcome>=24 [w=wt_totcore98], cluster(${cv})
local t = round(_b[_IbelXra_gr_1]/_se[_IbelXra_gr_1],.0001)
local p = round((1-normal(abs(`t')))*2,.0001)
di in red "T-stat on difference in exp effect for below vs above 13 is `t', p=`p'"

test ra_grp_exp _IbelXra_gr_1
test ra_grp_exp _IbelXra_gr_1 ra_grp_s8 _IbelXra_gra1 

* College
xi: reg coll_qual_pool_1820 i.below13*ra_grp_exp i.below13*ra_grp_s8 below13#(x_f_site*) if age_at_ra<23 & mto_kidsample==1 [w=wt_totcore98], cluster(${cv})
local t = round(_b[_IbelXra_gr_1]/_se[_IbelXra_gr_1],.0001)
local p = round((1-normal(abs(`t')))*2,.0001)
di in red "T-stat on difference in exp effect for below vs above 13 is `t', p=`p'"

test ra_grp_exp _IbelXra_gr_1
test ra_grp_exp _IbelXra_gr_1 ra_grp_s8 _IbelXra_gra1 

* Fraction of missing zips
gen missing_zip = missing(zip5)
tab missing_zip if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=24 & age_at_ra<13
tab missing_zip if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=24
reg missing_zip ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=24 & age_at_ra<13 [w=wt_totcore98], cluster(${cv})

* Fraction with flag_ssn == 1 who match to tax data 
preserve 
use ./data/mto_work_v5, clear
collapse (mean) intaxdata if flag_ssn == 1, by(mtch_ssn)
di in red "Tab of intaxdata gives fraction who match to IRS data (intaxdata ==1) for flag_ssn == 1"
tab intaxdata
restore 

* Notes on negative income observations (restricting to baseline income spec, pooling <13 and >=13
count if 					mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24
local N = r(N)
count if non_w2ssiui < 0 & mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24
local neg_non_w2ssiui = r(N)
count if hh_inc < 0 & 		mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24
local neg_hh_inc = r(N)
local neg_self_emp_inc_frac = `neg_non_w2ssiui'/`N'
local neg_hh_inc_frac = `neg_hh_inc'/`N'

di in red "Fraction of baseline (pooling <13 and >=13) sample with negative self-employment income: `neg_self_emp_inc_frac' (`neg_self_emp_inc'/`N')"
di in red "Fraction of baseline (pooling <13 and >=13) sample with negative household income: `neg_hh_inc_frac' (`neg_hh_inc'/`N')"
di in red "Mean spouse income for married individuals in baseline sample (age_at_ra<13): `r(mean)'"

* Mean non_w2ssiui income for filers with non_w2ssiui income below 12850
su non_w2ssiui if filed1040==1 & non_w2ssiui < 12850 & mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24 & age_at_ra<13
di in red "Mean non_w2ssiui income for filers with non_w2ssiui income below 12850: `r(mean)'"

* Mean father on birth certificate (Table 6 col 6) by site
tabulate ra_site if mto_kidsample == 1 & tax_yr==2012 & age_outcome>=21 & hasbirth==1 & ${agecond} & gnd_ind=="F" [w=wt_totcore98], su(hasbirth_dad_x100)

* The reason women have higher earnings is that they are more likely to have worked
tabulate gnd_ind if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& age_at_ra<13, su(w2wages)
tabulate gnd_ind if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& age_at_ra<13 & worked, su(w2wages)
tabulate gnd_ind if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& age_at_ra<13, su(indv_earn)
tabulate gnd_ind if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& age_at_ra<13 & worked, su(indv_earn)
tabulate gnd_ind worked if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 	& age_at_ra<13

* Mean indv income of spouse conditional on married==1, baseline sample
su indv_inc_spouse		if married==1 & mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24
su indv_inc_spouse_trim	if married==1 & mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) 	& age_outcome>=24

* The fraction of MTO kids born after 1991
use C:\Users\m2fqb\Documents\mto\data\irs_out2_20140624.dta , clear
keep if flag_SSNqual==1
gen mtokid = (f_svy_sample2007 == "YT" | f_svy_sample2007 ==  "EY" | f_svy_sample2007 ==  "YA")
gen yob=real(substr(mtch_dob,7,4))
gen cohort_post1991 = yob>1991
tab mtokid [w=wt_Totcore98], sum(cohort_post1991)

use C:\Users\m2fqb\Documents\mto\data\irs_out2_20140624.dta , clear

count
di as err "Number of unique obs. in raw HUD data: `r(N)'"
count if flag_SSNqual==1
di as err `"Number of individuals with "good" SSNs in raw HUD data: `r(N)'"'
count if year(date(mtch_dob,"MDY"))>1991 & !missing(mtch_dob)
di as err "Number of unique obs. in raw HUD data born on or after 1991: `r(N)'"
count if year(date(mtch_dob,"MDY"))>1991 & !missing(mtch_dob) & flag_SSNqual==1
di as err `"Number of individuals with "good" SSNs in raw HUD data born on or after 1991: `r(N)'"'

global fam_vars x_f_Ad* x_f_Hh_* x_f_Hood* x_f_Hous* x_f_site*
egen famid_synthetic = group($fam_vars) if wt_Totcore98>0
egen t = tag(famid_synthetic)
egen num_families = total(t)
su num_families
di as err `"Number of families in raw HUD data according to our "synthetic" family definition: `r(max)'"'

use ./data/mto_work_v5.dta, clear

keep if intaxdata==1
keep mtch_ssn
duplicates drop
count
di as err `"Number of individuals matched to tax data: `r(N)'"'

di "********************************************************************************************"

qui {

use C:\Users\m2fqb\Documents\mto\data\irs_out2_20140624.dta , clear
global fam_vars x_f_Ad* x_f_Hh_* x_f_Hood* x_f_Hous* x_f_site*
rename wt_Totcore98, lower
count if  wt_totcore98==0
local no_wt = r(N)
drop if wt_totcore98==0
egen famid_synthetic = group($fam_vars) if wt_totcore98>0

count if !missing(famid_synthetic) & wt_totcore98==0
local nummiss = r(N)

count
noi di as err "`r(N)' individuals in MTO (Excludes `no_wt' individuals with wt_totcore98==0. `nummiss' of these excluded individuals assigned to households.)"

count if missing(famid_synthetic)
local nummiss = r(N)

su famid_synthetic
local numhh = r(max)
noi di as err "`numhh' households in MTO"

gen yob = real(substr(mtch_dob, 7, 4))
count if yob<=1991
noi di as err "`r(N)' individuals 21 or older in 2012"

gen mto_kidsample = (f_svy_sample2007 == "YT" | f_svy_sample2007 ==  "EY" | f_svy_sample2007 ==  "YA")
gen ra_year = year(ra_date)
gen age_at_ra = ra_year-yob
count if mto_kidsample==1
local numkids = r(N)
noi di as err "`numkids' individuals <= 18 at time of RA"

count if mto_kidsample==1 & yob<=1991
local kids_old = r(N)
local frac_kids_old = `kids_old'/`numkids'
noi di as err "`kids_old' individuals <= 18 at time of RA and born in or before 1991 (`frac_kids_old')"

count if flag_SSNqual == 1 & yob<=1991
local ssn_count = r(N)
count if yob<=1991
local born_pre1991 = r(N)
local frac_SSN = `ssn_count'/`born_pre1991'
noi di as err "HUD collected SSNs for `ssn_count' individuals born in or before 1991 (`frac_SSN')"

use ./data/mto_work_v5.dta, clear
bysort mtch_ssn : keep if _n==1
count
local total = r(N)
count if intaxdata==1
local intaxdata = r(N)
local frac_intaxdata = `intaxdata'/`total'
noi di as err "Of the MTO records with a valid SSN, `intaxdata' (`frac_intaxdata') were successfully linked to the tax data."

use ./data/mto_work_v5.dta if intaxdata==1, clear

su coll_qual_pool_1820  if mto_kidsample == 1 & age_at_ra < 13 & !missing(coll_qual_pool_1820 ) & coll_pool_1820==1 & ra_group==3
di as err "The mean college quality conditional on attending college for younger children in the control group is `r(mean)'"
su coll_qual_pool_1820  if mto_kidsample == 1 & age_at_ra < 13 & !missing(coll_qual_pool_1820 ) & coll_pool_1820==0 & ra_group==3
di as err "For all those not attending college is: `r(mean)'"
}

log close

copy ./do/`filename'.do ${tabledir}/`filename'_`tstamp'.do

log close `filename'

****************************************************************************************************************************************************************
* Balance tests as in Table 1, restricting to estimation sample of Table 3, Panel A, Column 3 ****
****************************************************************************************************************************************************************

*Load analysis sample, restricting to matched obs
use ./data/mto_work_v5 if intaxdata==1, clear
reg indv_earn_trim ra_grp_exp ra_grp_s8 x_f_site* ${x_vars} if mto_kidsample == 1 &(tax_yr<=2012 & tax_yr>=2008) & age_outcome>=24 & age_at_ra < 13 [w=wt_totcore98], cluster(${cv})
keep if e(sample) 
* these lines fix the issue that pindex is never = 1 in the e(sample) - only reason we restrict to pindex == 1 in main code is to get one line per individual. 
duplicates drop mtch_ssn, force 
replace pindex = 1 

* Define list of variable we want to include in Table 1 (exclude age dummies); Multiply [0,1] variables by 100 to express as percentages
local vars "${x_vars}"
foreach v of local vars{
	if !regexm("`v'", "[Aa]ge")	{
		gen `v'_x100 = `v' * 100
		local usevars "`usevars' `v'_x100"
	}
	else local usevars "`usevars' `v'"
}

* Below we calculate the mean of the LHS variable within the control group and then run a regression of the LHS var on experimental and section 8 dummies. 
* I write all of the output to a csv because it is difficult to get the formatting we want using Stata programs like esttab

* Open temp file to write table output to. This will be converted to the actual output, table1.csv, below
tempfile temp
capture file close outfile
file open outfile using `temp', write replace
file write outfile ",ControlMean_b13,ExpCoef_b13,S8Coef_b13" _n

* Define an output format for estimates
global fmt "%9.1f"

* Keep track of total number of coefficients estimated and number of significant coefficients for text notes
local coef_count = 0
local p10_count = 0
local p05_count = 0
local p01_count = 0

local i=1
foreach v of local usevars {
	
	* Calculate mean of each variable within control group
	su `v' if ra_group==3 & mto_kidsample==1 & pindex==1 & age_at_ra<13 [w=wt_totcore98]
	local cont_b13 = `r(mean)'	
	
	* Test for statistically significant deviations from control mean in experimental and section 8 groups
	reg `v' ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample==1 & pindex==1 & age_at_ra<13 [w=wt_totcore98], cluster(${cv})
	local coef_count = `coef_count'+2
	
	* Store coefficients and significance stars to be printed below
	local b_exp_b13  = _b[ra_grp_exp]
	local se_exp_b13 = _se[ra_grp_exp]
	local star_exp_b13 = ""
	if abs(`b_exp_b13'/`se_exp_b13')>invnormal(.95) & abs(`b_exp_b13'/`se_exp_b13')<=invnormal(.975) { 
		local star_exp_b13 = "+"
		local p10_count = `p10_count'+1
	}
	if abs(`b_exp_b13'/`se_exp_b13')>invnormal(.975) & abs(`b_exp_b13'/`se_exp_b13')<=invnormal(.995) { 
		local star_exp_b13 = "*"
		local p05_count = `p05_count'+1
	}
	if abs(`b_exp_b13'/`se_exp_b13')>invnormal(.995) & abs(`b_exp_b13'/`se_exp_b13')<. {
		local star_exp_b13 = "**"
		local p01_count = `p01_count'+1
	}
	local b_s8_b13  = _b[ra_grp_s8]
	local se_s8_b13 = _se[ra_grp_s8]
	local star_s8_b13 = ""
	if abs(`b_s8_b13'/`se_s8_b13')>invnormal(.95) & abs(`b_s8_b13'/`se_s8_b13')<=invnormal(.975) {
		local star_s8_b13 = "+"
		local p10_count = `p10_count'+1
	}
	if abs(`b_s8_b13'/`se_s8_b13')>invnormal(.975) & abs(`b_s8_b13'/`se_s8_b13')<=invnormal(.995) {
		local star_s8_b13 = "*"
		local p05_count = `p05_count'+1
	}
	if abs(`b_s8_b13'/`se_s8_b13')>invnormal(.995) & abs(`b_s8_b13'/`se_s8_b13')<. {
		local star_s8_b13 = "**"
		local p01_count = `p01_count'+1
	}
	* Use value of 99999 as flag for missing coefficient to be parsed and dropped below
	if _b[ra_grp_exp]==0 & _se[ra_grp_exp]==0{
		local b_exp_b13 = 99999
		local se_exp_b13 = 99999
		local star_exp_b13 = ""
	}
	if _b[ra_grp_s8]==0 & _se[ra_grp_s8]==0{
		local b_s8_b13 = 99999
		local se_s8_b13 = 99999
		local star_s8_b13 = ""
	}
	
	* Print means, coefficients, standard errors, and significance stars to output csv file
	local rowname : word `i' of `vars'
	file write outfile `"`rowname',=""' ${fmt} (`cont_b13') `"", =""' ${fmt} (`b_exp_b13') `"`star_exp_b13'", =""' ${fmt} (`b_s8_b13') `"`star_s8_b13'""' _n
	file write outfile `" , ,="("' ${fmt} (`se_exp_b13') `")",="("'${fmt} (`se_s8_b13') `")""' _n

	local i=`i'+1
}

local ++i
* Count number of observation within each sample subgroup 
count if ra_group==3 & mto_kidsample==1 & age_at_ra<13 & intaxdata==1 & pindex==1 
local count_cont_b13 = r(N)
count if ra_group==1 & mto_kidsample==1 & age_at_ra<13 & intaxdata==1 & pindex==1 
local count_exp_b13 = r(N)
count if ra_group==2 & mto_kidsample==1 & age_at_ra<13 & intaxdata==1 & pindex==1 
count_s8_b13 = r(N)

* Print number of observations in subgroup at bottom of table
file write outfile "Count, `count_cont_b13',`count_exp_b13',`count_s8_b13'" _n
file close outfile

capture file close infile
file open infile using `temp', read

* Open csv file to write table 1 to
file open outfile using ${tabledir}/table1_rnr.csv, write replace

* Write each line from the temporary table1 file to the final output table. Replace 99999 placeholders for missing coefficients with blanks
file read infile line
while r(eof)==0{
	local out = subinstr(trim(itrim(`"`line'"'))," ","",.)
	local out = subinstr(`"`out'"', "(99999.0)", "", .)
	local out = subinstr(`"`out'"', "99999.0", "", .)
	file write outfile `"`out'"' _n
	file read infile line
}
file close infile 
file close outfile


****************************************************************************************************************************************************************
**** College outcomes as in Table 4 for later ages ****
****************************************************************************************************************************************************************

*Load analysis sample, restricting to matched obs
use ./data/mto_work_v5 if intaxdata==1, clear

* Add variables measuring college outcomes at later ages 
replace coll22 = . if cohort<1977|cohort>1990
replace coll23 = . if cohort<1976|cohort>1989
replace coll24 = . if cohort<1975|cohort>1988
replace coll25 = . if cohort<1974|cohort>1987

g coll22_x100 = coll22 * 100
g coll23_x100 = coll23 * 100
g coll24_x100 = coll24 * 100
g coll25_x100 = coll25 * 100

egen collby20_x100 = rowmax(coll18_x100 coll19_x100 coll20_x100) 
egen collby21_x100 = rowmax(coll18_x100 coll19_x100 coll20_x100 coll21_x100) 
egen collby22_x100 = rowmax(coll18_x100 coll19_x100 coll20_x100 coll21_x100 coll22_x100) 
egen collby23_x100 = rowmax(coll18_x100 coll19_x100 coll20_x100 coll21_x100 coll22_x100 coll23_x100) 
egen collby24_x100 = rowmax(coll18_x100 coll19_x100 coll20_x100 coll21_x100 coll22_x100 coll23_x100 coll24_x100) 
egen collby25_x100 = rowmax(coll18_x100 coll19_x100 coll20_x100 coll21_x100 coll22_x100 coll23_x100 coll24_x100 coll25_x100) 

* Age < 13
global agecond "age_at_ra<13"
eststo clear

_eststo coll_pool_1820:	reg coll_pool_1820_x100   	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond}  				 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll18: 		reg coll18_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll19: 		reg coll19_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll20: 		reg coll20_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll21: 		reg coll21_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll22: 		reg coll22_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll23: 		reg coll23_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans	
_eststo coll24: 		reg coll24_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll25: 		reg coll25_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820: 		reg coll_qual_pool_1820 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} 				 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq18: 			reg coll_qual_18 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq19: 			reg coll_qual_19 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq20: 			reg coll_qual_20 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq21: 			reg coll_qual_21 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq22: 			reg coll_qual_22 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq23: 			reg coll_qual_23 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq24: 			reg coll_qual_24 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq25: 			reg coll_qual_25 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo collby20:		reg collby20_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo collby21:		reg collby21_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo collby22:		reg collby22_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans	
_eststo collby23:		reg collby23_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans	
_eststo collby24:		reg collby24_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo collby25:		reg collby25_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
	
esttab using ${tabledir}/table4a_coll_below13_rnr.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(x_f*) starlevels( ${stars})

* Age >= 13
global agecond "age_at_ra>=13"
eststo clear

_eststo coll_pool_1820:	reg coll_pool_1820_x100   	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond}  				 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll18: 		reg coll18_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll19: 		reg coll19_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll20: 		reg coll20_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll21: 		reg coll21_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll22: 		reg coll22_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll23: 		reg coll23_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans	
_eststo coll24: 		reg coll24_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo coll25: 		reg coll25_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq1820: 		reg coll_qual_pool_1820 	ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} 				 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq18: 			reg coll_qual_18 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq19: 			reg coll_qual_19 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq20: 			reg coll_qual_20 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq21: 			reg coll_qual_21 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq22: 			reg coll_qual_22 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq23: 			reg coll_qual_23 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq24: 			reg coll_qual_24 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo kcq25: 			reg coll_qual_25 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo collby20:		reg collby20_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo collby21:		reg collby21_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo collby22:		reg collby22_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans	
_eststo collby23:		reg collby23_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans	
_eststo collby24:		reg collby24_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
_eststo collby25:		reg collby25_x100 			ra_grp_exp ra_grp_s8 x_f_site* if mto_kidsample == 1 & ${agecond} & tax_yr==2012 [w=wt_totcore98], cluster(${cv})
	addmeans
	
esttab using ${tabledir}/table4b_coll_13above_rnr.csv , nodepvar replace cells(b(star fmt(a3)) se(par fmt(a3)) p( fmt(a3))) stats(N num_individuals x_f_controls Sample sample_control_mean sample_mean, fmt(0 0 1)) drop(x_f*) starlevels( ${stars})


****************************************************************************************************************************************************************
**** Hypothesis test for Figure 1 ****
****************************************************************************************************************************************************************

* Define cluster variable - family ID 
global cv famid_synthetic 

*Load analysis sample, restricting to matched obs
use ./data/mto_work_v5 if intaxdata==1, clear

* Test: Include interaction by age of outcome measurement 
cap log close
log using test1, replace 
eststo clear

g ra_grp_exp_ao = ra_grp_exp * age_outcome 
g ra_grp_s8_ao = ra_grp_s8 * age_outcome 

g age_out = age_outcome if inrange(age_outcome,20,28)
egen site_ao = group(ra_site age_out)

_eststo out_interaction_b13:  areg indv_earn_trim ra_grp_exp ra_grp_s8 ra_grp_exp_ao ra_grp_s8_ao if mto_kidsample == 1 & inrange(age_outcome,20,28) & age_at_ra <  13 [w=wt_totcore98_0], cluster(${cv}) a(site_ao)
_eststo out_interaction_a13:  areg indv_earn_trim ra_grp_exp ra_grp_s8 ra_grp_exp_ao ra_grp_s8_ao if mto_kidsample == 1 & inrange(age_outcome,20,28) & age_at_ra >= 13 [w=wt_totcore98_0], cluster(${cv}) a(site_ao) 

esttab using ${tabledir}/figure1_test.csv, 	replace keep(ra_grp_exp_0 ra_grp_s8_0 ra_grp_exp_ao ra_grp_s8_ao) cells(b se p) stats(N) nodepvar

drop age_out site_ao 

log close
